import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, ViewChild, NgModule } from '@angular/core';
import * as i3$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i4 from '@annuadvent/ngx-common-ui/card';
import { CardModule } from '@annuadvent/ngx-common-ui/card';
import * as i5 from '@annuadvent/ngx-common-ui/collapsible';
import { CollapsibleModule } from '@annuadvent/ngx-common-ui/collapsible';
import * as i6 from '@annuadvent/ngx-common-ui/code-block';
import { CodeBlockModule } from '@annuadvent/ngx-common-ui/code-block';
import * as i7 from '@annuadvent/ngx-common-ui/modal';
import { ModalModule } from '@annuadvent/ngx-common-ui/modal';
import * as i2 from '@annuadvent/ngx-core/utils';
import { catchError, throwError, BehaviorSubject } from 'rxjs';
import { Buffer } from 'buffer';
import { json2xml, xml2json } from 'xml-js';
import * as i1$1 from '@annuadvent/ngx-core/app-config';
import * as i3 from '@angular/common/http';
import { getStorage, ref, uploadString, getDownloadURL, uploadBytes, deleteObject, list } from 'firebase/storage';
import * as i1 from '@annuadvent/ngx-tools/fire-common';
import * as i6$1 from '@annuadvent/ngx-common-ui/spinner';
import { SpinnerModule } from '@annuadvent/ngx-common-ui/spinner';
import * as i7$1 from '@annuadvent/ngx-common-ui/error';
import { ErrorModule } from '@annuadvent/ngx-common-ui/error';
import * as i8 from '@annuadvent/ngx-common-ui/search-box';
import { SearchBoxModule } from '@annuadvent/ngx-common-ui/search-box';
import Compressor from 'compressorjs';
import * as i2$1 from '@annuadvent/ngx-tools/fire-auth';
import * as i3$2 from '@angular/forms';
import { FormsModule } from '@angular/forms';

const sitemapFileName = 'sitemap.xml';
const defaultSitemapXmlStr = `
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://www.sitemaps.org/schemas/sitemap/0.9 http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd">
</urlset>
`;

class FireStorageSitemapService {
    constructor(fireCommonService) {
        this.fireCommonService = fireCommonService;
        this.sitemapFileName = sitemapFileName;
    }
    async uploadSitemap(sitemapData) {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileRef = ref(fireStorage, this.sitemapFileName);
        try {
            const uploadResult = await uploadString(fileRef, sitemapData);
            return true;
        }
        catch (error) {
            throw error;
        }
    }
    async sitemapExists() {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileRef = ref(fireStorage, this.sitemapFileName);
        try {
            const url = await getDownloadURL(fileRef);
            return url;
        }
        catch (error) {
            if (error.code !== 'storage/object-not-found') {
                throw error;
            }
            else {
                return '';
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageSitemapService, deps: [{ token: i1.FireCommonService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageSitemapService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageSitemapService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.FireCommonService }]; } });

class SitemapService {
    constructor(appConfigService, utilsSvc, httpClient, sitemapFireSvc) {
        this.appConfigService = appConfigService;
        this.utilsSvc = utilsSvc;
        this.httpClient = httpClient;
        this.sitemapFireSvc = sitemapFireSvc;
        if (typeof window !== undefined) {
            window.Buffer = window.Buffer || Buffer;
        }
    }
    /**
     * Reads the sitemap.xml
     * @date 2/21/2023 - 11:35:49 PM
     *
     * @public
     * @async
     * @returns {Promise<SitemapResponse>}
     */
    async getSitemapResponse(forceClear = false) {
        if (forceClear) {
            const sitemapStr = defaultSitemapXmlStr;
            return this.prepareSitemapResponse(sitemapStr);
        }
        const sitemapDownloadUrl = await this.sitemapFireSvc.sitemapExists();
        let sitemapStr = '';
        if (sitemapDownloadUrl) {
            const xmlResponseObserver$ = this.httpClient.get(sitemapDownloadUrl, {
                observe: 'body',
                responseType: 'text' // hack to avoid type error
            });
            return new Promise((resolve, reject) => {
                xmlResponseObserver$.pipe(catchError((error) => {
                    reject(error);
                    return throwError(() => {
                        return error;
                    });
                }))
                    .subscribe((sitemapStr) => {
                    resolve(this.prepareSitemapResponse(sitemapStr));
                });
            });
        }
        else {
            sitemapStr = defaultSitemapXmlStr;
            return this.prepareSitemapResponse(sitemapStr);
        }
    }
    /**
     * Saves both sitemap.xml to firebase storage
     * @date 2/28/2023 - 11:13:44 PM
     *
     * @public
     * @async
     * @param {Sitemap} sitemapJson
     * @returns {Promise<boolean>}
     */
    async saveSitemap(sitemapJson) {
        const xmlStr = this.jsonToXmlSitemap(sitemapJson);
        const result = await this.sitemapFireSvc.uploadSitemap(xmlStr);
        return result;
    }
    /**
     * Appends Urls to existing sitemap json.
     * @date 2/22/2023 - 1:35:03 AM
     *
     * @public
     * @param {Array<SitemapItem>} urls
     * @param {Sitemap} sitemap
     * @returns {Sitemap}
     */
    addUrlsToSitemapJson(urls, sitemap) {
        const newSitemap = this.utilsSvc.deepCopy(sitemap);
        if (!urls || !urls.length) {
            return newSitemap;
        }
        const clonedUrls = urls.map(url => this.utilsSvc.deepCopy(url));
        clonedUrls.forEach(url => {
            // check if url exist in sitemap
            const index = newSitemap.urlset.url.findIndex(u => u.loc._text === url.loc._text);
            if (index >= 0) {
                url.status = false;
                newSitemap.urlset.url.splice(index, 1);
            }
            else {
                url.status = true;
            }
        });
        newSitemap.urlset.url = [].concat(newSitemap.urlset.url, clonedUrls);
        return newSitemap;
    }
    /**
     * Converts json sitemap to xml sitemap string.
     * @date 2/22/2023 - 1:37:41 AM
     *
     * @public
     * @param {Sitemap} sitemap
     * @returns {string}
     */
    jsonToXmlSitemap(sitemap) {
        const sitemapStr = JSON.stringify(sitemap);
        const sitemapXmlStr = json2xml(sitemapStr, { compact: true, spaces: 4 });
        return sitemapXmlStr;
    }
    /**
     * Converts xml sitemap to json sitemap.
     * @date 2/22/2023 - 1:37:41 AM
     *
     * @public
     * @param {xmlStr} string
     * @returns {Sitemap}
     */
    xmlToJsonSitemap(xmlStr = '') {
        //Unescaping \" to " so as to parse xml.
        const newStr = xmlStr.replaceAll('\\"', '"');
        const jsonStr = xml2json(newStr, { compact: true });
        const sitemap = JSON.parse(jsonStr);
        return sitemap;
    }
    getLastUpdatedFromSitemap(sitemap) {
        const urls = sitemap?.urlset?.url || [];
        let lastUpdated = '';
        if (!urls.length) {
            return (new Date('1979-01-01')).toISOString();
        }
        lastUpdated = urls[0].lastmod._text;
        urls.forEach(url => {
            if ((new Date(url.lastmod._text)) > (new Date(lastUpdated))) {
                lastUpdated = url.lastmod._text;
            }
        });
        return lastUpdated;
    }
    prepareSitemapResponse(sitemapStr) {
        const sitemap = this.xmlToJsonSitemap(sitemapStr);
        const sitemapInfo = {
            updated: this.getLastUpdatedFromSitemap(sitemap)
        };
        // check if no urls in xml then add root and login urls.
        if (!sitemap.urlset?.url?.length) {
            sitemap.urlset.url = [
                {
                    loc: {
                        _text: `${this.appConfigService.config.apiBaseUrl}`
                    },
                    lastmod: {
                        _text: this.utilsSvc.currentDate
                    },
                    priority: {
                        _text: '1.00'
                    }
                },
                {
                    loc: {
                        _text: `${this.appConfigService.config.apiBaseUrl}/login`
                    },
                    lastmod: {
                        _text: this.utilsSvc.currentDate
                    },
                    priority: {
                        _text: '1.00'
                    }
                },
                {
                    loc: {
                        _text: `${this.appConfigService.config.apiBaseUrl}/genre`
                    },
                    lastmod: {
                        _text: this.utilsSvc.currentDate
                    },
                    priority: {
                        _text: '1.00'
                    }
                },
                {
                    loc: {
                        _text: `${this.appConfigService.config.apiBaseUrl}/stories`
                    },
                    lastmod: {
                        _text: this.utilsSvc.currentDate
                    },
                    priority: {
                        _text: '1.00'
                    }
                }
            ];
        }
        const sitemapResponse = {
            sitemapInfo,
            sitemap
        };
        return sitemapResponse;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapService, deps: [{ token: i1$1.AppConfigService }, { token: i2.UtilsService }, { token: i3.HttpClient }, { token: FireStorageSitemapService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$1.AppConfigService }, { type: i2.UtilsService }, { type: i3.HttpClient }, { type: FireStorageSitemapService }]; } });

class SitemapComponent {
    constructor(utilsSvc, sitemapService) {
        this.utilsSvc = utilsSvc;
        this.sitemapService = sitemapService;
        this.newUrls = [];
        this.createSitemapClicked = new EventEmitter();
        this.loadSitemapClicked = new EventEmitter();
        this.saveClicked = new EventEmitter();
        this.previewClicked = new EventEmitter();
        this.checkNewUrlsClicked = new EventEmitter();
        this.currentSitemapCollapsed = false;
        this.checkNewUrlsCollapsed = false;
        this.previewCollapsed = false;
        this.newUrlsStatus = {};
        this.sitemapXmlStr = '';
        this.showXmlModal = false;
    }
    loadSitemap(event) {
        event.preventDefault();
        this.currentSitemapCollapsed = true;
        this.loadSitemapClicked.emit();
    }
    createSitemap(event) {
        event.preventDefault();
        this.currentSitemapCollapsed = true;
        this.createSitemapClicked.emit();
    }
    checkNewUrls(event) {
        event.preventDefault();
        this.checkNewUrlsCollapsed = true;
        this.checkNewUrlsClicked.emit();
    }
    previewSitemap(event) {
        event.preventDefault();
        this.previewCollapsed = true;
        this.previewClicked.emit();
    }
    saveSitemap(event) {
        event.preventDefault();
        const clonedNewSitemap = this.utilsSvc.deepCopy(this.newSitemap);
        clonedNewSitemap.urlset.url.forEach(url => {
            delete url.status;
        });
        this.saveClicked.emit(clonedNewSitemap);
    }
    showXmlString(event, sitemapJson) {
        event.preventDefault();
        this.sitemapXmlStr = this.sitemapService.jsonToXmlSitemap(sitemapJson);
        this.showXmlModal = true;
    }
    xmlModalClosed() {
        this.showXmlModal = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapComponent, deps: [{ token: i2.UtilsService }, { token: SitemapService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: SitemapComponent, selector: "anu-sitemap", inputs: { sitemap: "sitemap", sitemapInfo: "sitemapInfo", newUrls: "newUrls", newSitemap: "newSitemap" }, outputs: { createSitemapClicked: "createSitemapClicked", loadSitemapClicked: "loadSitemapClicked", saveClicked: "saveClicked", previewClicked: "previewClicked", checkNewUrlsClicked: "checkNewUrlsClicked" }, ngImport: i0, template: "<div class=\"flex-container center\">\r\n    <div class=\"container\">\r\n        <div class=\"row\">\r\n            <!-- Current Sitemap Urls -->\r\n            <anu-card class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <div class=\"row stretch\">\r\n                        <a href=\"#\" class=\"\" (click)=\"loadSitemap($event)\">Load sitemap.xml</a>\r\n                        <a href=\"#\" class=\"\" (click)=\"createSitemap($event)\">Create sitemap.xml</a>\r\n                    </div>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible class=\"spacing-vertical\" *ngIf=\"sitemapInfo || sitemap\"\r\n                        [collapsed]=\"currentSitemapCollapsed\" [hamBurgerClassNames]=\"['size-md']\"\r\n                        [isDropdownStyle]=\"true\" (changed)=\"currentSitemapCollapsed = !currentSitemapCollapsed\">\r\n                        <anu-collapsible-header>Current Sitemap</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <h3 *ngIf=\"sitemapInfo\">Sitemap was last updated on:\r\n                                <strong>{{sitemapInfo.updated}}</strong>\r\n                            </h3>\r\n                            <ol *ngIf=\"sitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of sitemap.urlset.url\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, sitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n            <!-- New Urls to be added -->\r\n            <anu-card *ngIf=\"sitemap\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"checkNewUrls($event)\">Check for new Urls</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newUrls\" class=\"spacing-vertical\" [collapsed]=\"checkNewUrlsCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"checkNewUrlsCollapsed = !checkNewUrlsCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">Sitemap new Urls</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <ol *ngIf=\"newUrls?.length\">\r\n                                <li *ngFor=\"let url of newUrls\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <p *ngIf=\"!newUrls?.length\" class=\"warning\">No new urls available</p>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n\r\n            <!-- Preview Merged Urls -->\r\n            <anu-card *ngIf=\"newUrls?.length\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"previewSitemap($event)\">Preview sitemap.xml (Ready to update)</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newSitemap\" class=\"spacing-vertical\" [collapsed]=\"previewCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"previewCollapsed = !previewCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">New Sitemap (Ready to\r\n                            update)</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <div class=\"row\">\r\n                                <span class=\"spacing-half spacing-around\"><small><strong>LEGENDS:</strong>\r\n                                    </small></span>\r\n                                <span class=\"spacing-half spacing-around\"><small>No change</small></span>\r\n                                <span class=\"spacing-half spacing-around success\"><small>Added</small></span>\r\n                                <span class=\"spacing-half spacing-around warning\"><small>Updated</small></span>\r\n                            </div>\r\n                            <ol *ngIf=\"newSitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of newSitemap.urlset.url\" [class.success]=\"url.status === true\"\r\n                                    [class.warning]=\"url.status === false\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, newSitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n                <anu-card-footer *ngIf=\"newSitemap\">\r\n                    <a href=\"#\" class=\"btn btn-primary\" (click)=\"saveSitemap($event)\">Save</a>\r\n                </anu-card-footer>\r\n            </anu-card>\r\n        </div>\r\n    </div>\r\n</div>\r\n\r\n<anu-modal [cancelLabel]=\"'Cancel'\" [enableCancel]=\"true\" [enableClose]=\"true\" [enableOk]=\"false\" [okLabel]=\"'Ok'\"\r\n    [opened]=\"showXmlModal\" [modalTitle]=\"'XML view of sitemap'\" (cancelClick)=\"xmlModalClosed()\">\r\n\r\n    <anu-code-block class=\"col-12\" [enableEdit]='false' [language]=\"'xml'\" [source]=\"sitemapXmlStr\">\r\n    </anu-code-block>\r\n\r\n</anu-modal>", styles: [""], dependencies: [{ kind: "directive", type: i3$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i4.CardComponent, selector: "anu-card", inputs: ["isRowLayout", "imageCssClasses", "contentCssClasses"] }, { kind: "component", type: i4.CardTitleComponent, selector: "anu-card-title" }, { kind: "component", type: i4.CardBodyComponent, selector: "anu-card-body" }, { kind: "component", type: i4.CardFooterComponent, selector: "anu-card-footer" }, { kind: "component", type: i5.CollapsibleComponent, selector: "anu-collapsible", inputs: ["collapsed", "hamBurgerClassNames", "isDropdownStyle"], outputs: ["changed"] }, { kind: "component", type: i5.CollapsibleHeaderComponent, selector: "anu-collapsible-header" }, { kind: "component", type: i5.CollapsibleContentComponent, selector: "anu-collapsible-content" }, { kind: "component", type: i6.CodeBlockComponent, selector: "anu-code-block", inputs: ["source", "language", "enableEdit"], outputs: ["changed", "sourceModalOpenStatusChanged"] }, { kind: "component", type: i7.ModalComponent, selector: "anu-modal", inputs: ["opened", "modalTitle", "okLabel", "cancelLabel", "enableOk", "enableCancel", "enableClose"], outputs: ["okClick", "cancelClick"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: SitemapComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-sitemap', template: "<div class=\"flex-container center\">\r\n    <div class=\"container\">\r\n        <div class=\"row\">\r\n            <!-- Current Sitemap Urls -->\r\n            <anu-card class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <div class=\"row stretch\">\r\n                        <a href=\"#\" class=\"\" (click)=\"loadSitemap($event)\">Load sitemap.xml</a>\r\n                        <a href=\"#\" class=\"\" (click)=\"createSitemap($event)\">Create sitemap.xml</a>\r\n                    </div>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible class=\"spacing-vertical\" *ngIf=\"sitemapInfo || sitemap\"\r\n                        [collapsed]=\"currentSitemapCollapsed\" [hamBurgerClassNames]=\"['size-md']\"\r\n                        [isDropdownStyle]=\"true\" (changed)=\"currentSitemapCollapsed = !currentSitemapCollapsed\">\r\n                        <anu-collapsible-header>Current Sitemap</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <h3 *ngIf=\"sitemapInfo\">Sitemap was last updated on:\r\n                                <strong>{{sitemapInfo.updated}}</strong>\r\n                            </h3>\r\n                            <ol *ngIf=\"sitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of sitemap.urlset.url\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, sitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n            <!-- New Urls to be added -->\r\n            <anu-card *ngIf=\"sitemap\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"checkNewUrls($event)\">Check for new Urls</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newUrls\" class=\"spacing-vertical\" [collapsed]=\"checkNewUrlsCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"checkNewUrlsCollapsed = !checkNewUrlsCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">Sitemap new Urls</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <ol *ngIf=\"newUrls?.length\">\r\n                                <li *ngFor=\"let url of newUrls\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <p *ngIf=\"!newUrls?.length\" class=\"warning\">No new urls available</p>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n            </anu-card>\r\n\r\n\r\n            <!-- Preview Merged Urls -->\r\n            <anu-card *ngIf=\"newUrls?.length\" class=\"col-12 shadow spacing\">\r\n                <anu-card-title>\r\n                    <a href=\"#\" class=\"\" (click)=\"previewSitemap($event)\">Preview sitemap.xml (Ready to update)</a>\r\n                </anu-card-title>\r\n                <anu-card-body>\r\n                    <anu-collapsible *ngIf=\"newSitemap\" class=\"spacing-vertical\" [collapsed]=\"previewCollapsed\"\r\n                        [hamBurgerClassNames]=\"['size-md']\" [isDropdownStyle]=\"true\"\r\n                        (changed)=\"previewCollapsed = !previewCollapsed\">\r\n                        <anu-collapsible-header class=\"bg-secondary\">New Sitemap (Ready to\r\n                            update)</anu-collapsible-header>\r\n                        <anu-collapsible-content>\r\n                            <div class=\"row\">\r\n                                <span class=\"spacing-half spacing-around\"><small><strong>LEGENDS:</strong>\r\n                                    </small></span>\r\n                                <span class=\"spacing-half spacing-around\"><small>No change</small></span>\r\n                                <span class=\"spacing-half spacing-around success\"><small>Added</small></span>\r\n                                <span class=\"spacing-half spacing-around warning\"><small>Updated</small></span>\r\n                            </div>\r\n                            <ol *ngIf=\"newSitemap?.urlset?.url\">\r\n                                <li *ngFor=\"let url of newSitemap.urlset.url\" [class.success]=\"url.status === true\"\r\n                                    [class.warning]=\"url.status === false\">\r\n                                    {{url.lastmod._text}} | {{url.priority._text}} | {{url.loc._text}}\r\n                                </li>\r\n                            </ol>\r\n                            <div class=\"row right spacing-vertical\">\r\n                                <a href=\"#\" title=\"View in xml\" (click)=\"showXmlString($event, newSitemap)\">XML</a>\r\n                            </div>\r\n                        </anu-collapsible-content>\r\n                    </anu-collapsible>\r\n                </anu-card-body>\r\n                <anu-card-footer *ngIf=\"newSitemap\">\r\n                    <a href=\"#\" class=\"btn btn-primary\" (click)=\"saveSitemap($event)\">Save</a>\r\n                </anu-card-footer>\r\n            </anu-card>\r\n        </div>\r\n    </div>\r\n</div>\r\n\r\n<anu-modal [cancelLabel]=\"'Cancel'\" [enableCancel]=\"true\" [enableClose]=\"true\" [enableOk]=\"false\" [okLabel]=\"'Ok'\"\r\n    [opened]=\"showXmlModal\" [modalTitle]=\"'XML view of sitemap'\" (cancelClick)=\"xmlModalClosed()\">\r\n\r\n    <anu-code-block class=\"col-12\" [enableEdit]='false' [language]=\"'xml'\" [source]=\"sitemapXmlStr\">\r\n    </anu-code-block>\r\n\r\n</anu-modal>" }]
        }], ctorParameters: function () { return [{ type: i2.UtilsService }, { type: SitemapService }]; }, propDecorators: { sitemap: [{
                type: Input
            }], sitemapInfo: [{
                type: Input
            }], newUrls: [{
                type: Input
            }], newSitemap: [{
                type: Input
            }], createSitemapClicked: [{
                type: Output
            }], loadSitemapClicked: [{
                type: Output
            }], saveClicked: [{
                type: Output
            }], previewClicked: [{
                type: Output
            }], checkNewUrlsClicked: [{
                type: Output
            }] } });

var ImageBrowserLoaderEnum;
(function (ImageBrowserLoaderEnum) {
    ImageBrowserLoaderEnum["imageFile"] = "imageFile";
    ImageBrowserLoaderEnum["imageFiles"] = "imageFiles";
    ImageBrowserLoaderEnum["loadMore"] = "loadMore";
    ImageBrowserLoaderEnum["uploadImageFile"] = "uploadImageFile";
})(ImageBrowserLoaderEnum || (ImageBrowserLoaderEnum = {}));
;

class FireStorageImageService {
    constructor(fireCommonService) {
        this.fireCommonService = fireCommonService;
        this.baseStorageUrl = '';
        this.baseStorageUrl = this.fireCommonService.firebaseConfig.storage.baseStorageUrl;
    }
    buildImageUrl(fullPathWithFileName, userId) {
        return (this.baseStorageUrl +
            '/' +
            (userId ? `${userId}/${fullPathWithFileName}` : '' + fullPathWithFileName));
    }
    getUploadImageValidationText() {
        const { maxKBs, maxWidth, maxHeight, minWidth, minHeight } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        return `Allowed width is ${minWidth}px to ${maxWidth}px, height is ${minHeight}px to ${maxHeight}px and size is up to ${maxKBs}KBs`;
    }
    async validateImage(imageData) {
        if (!imageData)
            return 'Empty Image';
        const { maxKBs } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        // Type Check
        if (imageData.type.indexOf('image/') < 0) {
            return `Not a valid image file. Please try uploading a valid jpg/gif/png image file.`;
        }
        //Size Check
        if (imageData.size > maxKBs * 1024) {
            return `Image size exceeds the limit of ${maxKBs}KBs`;
        }
        // Dimension Check.
        return await this.validateImageDimension(imageData);
    }
    async validateImageDimension(imageData) {
        const { maxWidth, maxHeight, minWidth, minHeight } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        var reader = new FileReader();
        //Read the contents of Image File.
        reader.readAsDataURL(imageData);
        const promise = new Promise((resolve, reject) => {
            reader.onload = (e) => {
                //Initiate the JavaScript Image object.
                const image = new Image();
                //Set the Base64 string return from FileReader as source.
                image.src = e.target.result;
                image.onload = () => {
                    // Natural size is the actual image size regardless of rendering.
                    // The 'normal' `width`/`height` are for the **rendered** size.
                    const width = image.naturalWidth;
                    const height = image.naturalHeight;
                    if (width > maxWidth ||
                        minWidth < minWidth ||
                        maxHeight > maxHeight ||
                        minHeight < minHeight) {
                        resolve(`Image dimensions are ${width}px X ${height}px and does not meet the requirement. Allowed width = ${minWidth}px to ${maxWidth}px and allowed height = ${minHeight}px to ${maxHeight}px`);
                    }
                    else {
                        resolve('');
                    }
                };
                // Reject promise on error
                image.onerror = (error) => {
                    reject('Error loading Image');
                };
            };
        });
        return promise;
    }
    async uploadImage(fullPathWithFileName, imageData, overWrite = false, userId = '', isBas64 = false) {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(fullPathWithFileName, userId);
        const fileRef = ref(fireStorage, fileUrl);
        // If exists
        if (!overWrite) {
            try {
                const isExists = await getDownloadURL(fileRef);
                if (isExists) {
                    throw new Error('Image already exists -' + fullPathWithFileName);
                }
            }
            catch (error) {
                if (error.code !== 'storage/object-not-found') {
                    throw error;
                }
            }
        }
        try {
            if (isBas64) {
                imageData = await this.compressBase64ToJpeg(imageData);
            }
            const uploadResult = await uploadBytes(fileRef, imageData);
            const downloadUrl = await this.getImageUrl(fullPathWithFileName, userId);
            const imageFileInfo = {
                name: uploadResult.ref.name,
                fullPath: uploadResult.ref.fullPath,
                downloadUrl,
            };
            return imageFileInfo;
        }
        catch (error) {
            throw error;
        }
    }
    async getImageUrl(fullPathWithFileName, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(fullPathWithFileName, userId);
        const fileRef = ref(fireStorage, fileUrl);
        try {
            const url = await getDownloadURL(fileRef);
            return url;
        }
        catch (error) {
            throw error;
        }
    }
    async deleteImage(fullPathWithFileName, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(fullPathWithFileName, userId);
        const fileRef = ref(fireStorage, fileUrl);
        try {
            await deleteObject(fileRef);
            return fileUrl;
        }
        catch (error) {
            throw error;
        }
    }
    async getImagesList(userId = '', pageSize = 10, nextPageToken = null) {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const lookinFolder = this.buildImageUrl('', userId);
        const listRef = ref(fireStorage, lookinFolder);
        try {
            const listOptions = { maxResults: pageSize };
            if (nextPageToken)
                listOptions.pageToken = nextPageToken;
            const imageList = await list(listRef, listOptions);
            const imageFileInfoList = {
                imageFiles: imageList.items.map((img) => ({
                    name: img.name,
                    fullPath: img.fullPath,
                    downloadUrl: '',
                })),
                nextPageToken: imageList.nextPageToken,
            };
            return imageFileInfoList;
        }
        catch (error) {
            throw error;
        }
    }
    async imageExists(fullPathWithFileName, userId = '') {
        const fireStorage = getStorage(this.fireCommonService.initOrGetFirebaseApp(), this.fireCommonService.firebaseConfig.app.storageBucket);
        const fileUrl = this.buildImageUrl(fullPathWithFileName, userId);
        const fileRef = ref(fireStorage, fileUrl);
        try {
            const url = await getDownloadURL(fileRef);
            return !!url;
        }
        catch (error) {
            if (error.code !== 'storage/object-not-found') {
                throw error;
            }
            else {
                return false;
            }
        }
    }
    async compressBase64ToJpeg(base64Image) {
        const { maxWidth } = this.fireCommonService.firebaseConfig.storage.imageDimensions;
        return new Promise((resolve, reject) => {
            // Convert base64 to blob
            const blob = this.dataURItoBlob(base64Image, 'image/jpeg');
            const compressOptions = {
                strict: true,
                checkOrientation: true,
                width: maxWidth,
                height: maxWidth / 2,
                maxWidth: maxWidth,
                maxHeight: maxWidth / 2,
                resize: 'cover',
                convertTypes: 'image/jpg',
                quality: 0.7,
                success: (compressedBlob) => {
                    // Handle the compressed image blob
                    resolve(compressedBlob);
                },
                error: (error) => {
                    reject(`Image compression error:${error.message}`);
                },
            };
            // Create an image compressor instance
            new Compressor(blob, compressOptions);
        });
    }
    dataURItoBlob(dataURI, type) {
        const byteString = atob(dataURI);
        const arrayBuffer = new ArrayBuffer(byteString.length);
        const uint8Array = new Uint8Array(arrayBuffer);
        for (let i = 0; i < byteString.length; i++) {
            uint8Array[i] = byteString.charCodeAt(i);
        }
        return new Blob([uint8Array], { type });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageImageService, deps: [{ token: i1.FireCommonService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageImageService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageImageService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.FireCommonService }]; } });

class ImageBrowserService {
    constructor(fireStorageImageService, fireAuthService) {
        this.fireStorageImageService = fireStorageImageService;
        this.fireAuthService = fireAuthService;
        this.imageFiles$ = new BehaviorSubject([]);
        this.selected$ = new BehaviorSubject(null);
        this.previewOnImages$ = new BehaviorSubject({});
        this._pageSize = 10;
        this.userId = '';
        this.nextPageToken = null;
        // If logged in user changed or loged off, then list should be cleared.
        this.fireAuthService.authStateChanged().subscribe((user) => {
            if (user?.id && user.id !== this.userId) {
                this.clear();
                this.userId = user.id;
            }
            else if (!user?.id) {
                this.clear();
                this.userId = null;
            }
        });
    }
    clear() {
        this.imageFiles$.next([]);
        this.previewOnImages$.next({});
        this.selected$.next(null);
    }
    get pageSize() {
        return this._pageSize;
    }
    set pageSize(v) {
        this._pageSize = v;
    }
    get imageFiles() {
        return this.imageFiles$.asObservable();
    }
    get selected() {
        return this.selected$.asObservable();
    }
    get previewOnImages() {
        return this.previewOnImages$.asObservable();
    }
    async refreshList() {
        this.userId = this.fireAuthService.getCurrentUserId();
        if (!this.userId) {
            throw new Error('User is not authenticated or logged in.');
        }
        const imageFileInfoList = await this.fireStorageImageService.getImagesList(this.userId, this.pageSize, this.nextPageToken)
            .catch(err => {
            throw err;
        });
        this.nextPageToken = imageFileInfoList?.nextPageToken || null;
        this.uploadValidationText = this.fireStorageImageService.getUploadImageValidationText();
        this.previewOnImages$.next({});
        this.selected$.next(null);
        this.imageFiles$.next(imageFileInfoList?.imageFiles || []);
        return imageFileInfoList?.imageFiles || [];
    }
    async loadMore() {
        this.userId = this.fireAuthService.getCurrentUserId();
        if (!this.userId) {
            throw new Error('User is not authenticated or logged in.');
        }
        const imageFileInfoList = await this.fireStorageImageService.getImagesList(this.userId, this.pageSize, this.nextPageToken)
            .catch(err => {
            throw err;
        });
        this.nextPageToken = imageFileInfoList?.nextPageToken || null;
        this.imageFiles$.next([
            ...this.imageFiles$.value,
            ...(imageFileInfoList?.imageFiles || [])
        ]);
        return imageFileInfoList?.imageFiles || [];
    }
    async delete(imageFile) {
        this.userId = this.fireAuthService.getCurrentUserId();
        if (!this.userId) {
            throw new Error('User is not authenticated or logged in.');
        }
        const deletedFileFullPath = await this.fireStorageImageService.deleteImage(imageFile?.name, this.userId)
            .catch(err => {
            throw err;
        });
        // Successful delete, remove it from the existing list too;
        this.imageFiles$.next(this.imageFiles$.value.filter(iFile => iFile.fullPath !== deletedFileFullPath));
        return imageFile;
    }
    async upload(imagePathWithFileName, imageData) {
        this.userId = this.fireAuthService.getCurrentUserId();
        if (!this.userId) {
            throw new Error('User is not authenticated or logged in.');
        }
        const errorMessage = await this.fireStorageImageService.validateImage(imageData)
            .catch(err => err);
        if (errorMessage) {
            throw new Error(errorMessage);
        }
        const uploadedImageFile = await this.fireStorageImageService.uploadImage(imagePathWithFileName, imageData, false, this.userId, false)
            .catch(err => {
            throw err;
        });
        // Add uploaded file to 
        this.imageFiles$.next([
            uploadedImageFile,
            ...this.imageFiles$.value
        ]);
        return uploadedImageFile;
    }
    selectImageFile(imageFile) {
        this.selected$.next(imageFile);
    }
    previewImageFile(imageFullFileName, previewOn = true) {
        this.previewOnImages$.next({
            ...this.previewOnImages$.value,
            [imageFullFileName]: previewOn
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: ImageBrowserService, deps: [{ token: FireStorageImageService }, { token: i2$1.FireAuthService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: ImageBrowserService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: ImageBrowserService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: FireStorageImageService }, { type: i2$1.FireAuthService }]; } });

const PAGE_SIZE = 30;
/**
 * Image Browser component allows logged in user to browse, select and upload images to fire store.
 * Image Browser is implemented upon Image Browser service (ImageBrowserService), that exposes observables
 * to listen to any changes to the components data.
 *
 * So It is recommended to use ImageBrowserService and its exposed observables to work with this component.
 */
class ImageBrowserComponent {
    constructor(imageBrowserService) {
        this.imageBrowserService = imageBrowserService;
        this.imageFiles = [];
        this.selectedImageFile = null;
        this.previewOnImages = {};
        this.imagesFilesFiltered = [];
        this.imagesFilesFilteredCount = 0;
        this.uploadHelpText = '';
        this.choosenFileName = '';
        this.choosenFile = null;
        this.nextPageToken = null;
        this.loading = {};
        this.deleteConfirmModalOpened = false;
        this.toDeleteImageFile = null;
        this.imageBrowserService.pageSize = PAGE_SIZE;
        // Subscriptions
        this.imageBrowserService.imageFiles.subscribe((imageFiles => {
            this.imageFiles = imageFiles;
            this.nextPageToken = this.imageBrowserService.nextPageToken;
            this.uploadHelpText = this.imageBrowserService.uploadValidationText;
        }));
        this.imageBrowserService.selected.subscribe((imageFile => {
            this.selectedImageFile = imageFile;
        }));
        this.imageBrowserService.previewOnImages.subscribe((previewOnImages => {
            this.previewOnImages = previewOnImages;
        }));
    }
    ngOnInit() {
    }
    setErrorAndLoading(loaderName, err = null, loading = true, subLoaderName = '') {
        if (err) {
            this.error = { code: err.code || err.status || 'UNKNOWN', message: err.message || err.text || err.toString() };
        }
        else {
            this.error = null;
        }
        if (subLoaderName) {
            this.loading.imageFile = this.loading.imageFile || {};
            this.loading.imageFile[subLoaderName] = loading;
        }
        else {
            switch (loaderName) {
                case ImageBrowserLoaderEnum.imageFiles:
                    this.loading.imageFiles = loading;
                    break;
                case ImageBrowserLoaderEnum.loadMore:
                    this.loading.loadMore = loading;
                    break;
                case ImageBrowserLoaderEnum.uploadImageFile:
                    this.loading.uploadImageFile = loading;
                    break;
            }
        }
    }
    onImageListFilter(imageFilesFiltered) {
        this.imagesFilesFiltered = imageFilesFiltered;
        setTimeout(() => {
            this.imagesFilesFilteredCount = this.imagesFilesFiltered?.length || 0;
        });
    }
    refreshClick(event) {
        event.preventDefault();
        this.setErrorAndLoading(ImageBrowserLoaderEnum.imageFiles);
        this.imageBrowserService.refreshList()
            .then(() => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.imageFiles, null, false);
        }, (err) => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.imageFiles, err, false);
        });
    }
    selectClick(event, imageFile) {
        event.preventDefault();
        this.imageBrowserService.selectImageFile(imageFile);
    }
    loadMoreClick(event) {
        event.preventDefault();
        this.setErrorAndLoading(ImageBrowserLoaderEnum.loadMore);
        this.imageBrowserService.loadMore()
            .then(() => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.loadMore, null, false);
        }, (err) => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.loadMore, err, false);
        });
    }
    deleteImageOkClick() {
        this.deleteConfirmModalOpened = false;
        this.setErrorAndLoading(ImageBrowserLoaderEnum.imageFile, null, true, this.toDeleteImageFile.fullPath);
        this.imageBrowserService.delete(this.toDeleteImageFile)
            .then(() => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.imageFile, null, false, this.toDeleteImageFile.fullPath);
            this.toDeleteImageFile = null;
        }, (err) => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.imageFile, err, false, this.toDeleteImageFile.fullPath);
            this.toDeleteImageFile = null;
        });
    }
    deleteImageCancelClick() {
        this.deleteConfirmModalOpened = false;
        this.toDeleteImageFile = null;
    }
    deleteClick(event, imageFile) {
        event.preventDefault();
        this.deleteConfirmModalOpened = true;
        this.toDeleteImageFile = imageFile;
    }
    previewClick(event, imageFile) {
        event.preventDefault();
        this.imageBrowserService.previewImageFile(imageFile.fullPath);
    }
    onFileChange(event) {
        this.choosenFileName = '';
        if (event.target.files.length > 0) {
            this.choosenFile = event.target.files[0];
            this.choosenFileName = this.choosenFile.name;
        }
    }
    uploadClick() {
        const fileInputEl = this.fileEl.nativeElement;
        fileInputEl.value = '';
        this.choosenFileName = '';
        fileInputEl.click();
    }
    uploadFileClick(event) {
        event.preventDefault();
        if (!this.choosenFileName || !this.choosenFile)
            return;
        this.setErrorAndLoading(ImageBrowserLoaderEnum.uploadImageFile);
        this.imageBrowserService.upload(this.choosenFileName || this.choosenFile.name, this.choosenFile)
            .then((imageFile) => {
            this.imageBrowserService.selectImageFile(imageFile);
            this.setErrorAndLoading(ImageBrowserLoaderEnum.uploadImageFile, null, false);
        }, (err) => {
            this.setErrorAndLoading(ImageBrowserLoaderEnum.uploadImageFile, err, false);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: ImageBrowserComponent, deps: [{ token: ImageBrowserService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: ImageBrowserComponent, selector: "anu-image-browser", inputs: { imageFiles: "imageFiles" }, viewQueries: [{ propertyName: "fileEl", first: true, predicate: ["fileInput"], descendants: true }], ngImport: i0, template: "<anu-error class=\"container\" *ngIf=\"error\" [code]=\"error?.code\" [message]=\"error?.message\"></anu-error>\r\n\r\n<div class=\"row\">\r\n    <div class=\"col-sm-12 col-md-6 col-lg-6\">\r\n        <anu-card class=\"border-round shadow spacing-half relative\">\r\n            <anu-card-title>\r\n                <h3>Upload Image</h3>\r\n            </anu-card-title>\r\n            <anu-card-body>                \r\n                <span *ngIf=\"uploadHelpText\"><small>{{uploadHelpText}}</small></span>\r\n                <div class=\"form-group container center\">\r\n                    <input #fileInput id=\"file\" type=\"file\" class=\"\" (change)=\"onFileChange($event)\" />\r\n                    <input type=\"button\" class=\"btn\" (click)=\"uploadClick()\" value=\"Choose file to upload...\">\r\n                    <input type=\"text\" class=\"spacing-around-vertical-half\" [(ngModel)]=\"choosenFileName\" placeholder=\"No image to upload\"/>\r\n                    <a class=\"btn primary spacing-around-vertical-half\" href=\"#\" (click)=\"uploadFileClick($event)\" title=\"Upload\">Upload</a>\r\n                </div>\r\n                <anu-spinner class=\"col-12\" [show]=\"loading.uploadImageFile\"></anu-spinner>\r\n            </anu-card-body>\r\n        </anu-card>\r\n    </div>\r\n    <div class=\"col-sm-12 col-md-6 col-lg-6\">\r\n        <img *ngIf=\"selectedImageFile\" class=\"selected-image shadow\" [src]=\"'getImage?imageId=' + selectedImageFile?.fullPath\" [alt]=\"selectedImageFile?.name\" />\r\n    </div>\r\n</div>\r\n\r\n\r\n<div class=\"row border center\">\r\n    <!-- Count -->\r\n    <strong>{{imagesFilesFilteredCount}} / {{imageFiles?.length || 0}}</strong>\r\n    <!-- Image Files filter -->\r\n    <anu-search-box classs=\"col-12\" [items]=\"imageFiles\" [keys]=\"['name']\"\r\n        (changed)=\"onImageListFilter($event)\"></anu-search-box>\r\n    <!-- Reload list  -->\r\n    <a class=\"spacing\" href=\"#\" (click)=\"refreshClick($event)\" title=\"Reload List\">\u27F3 Reload</a>\r\n</div>\r\n<div class=\"row border\">    \r\n    <ng-container *ngFor=\"let imgFile of imagesFilesFiltered\">\r\n        <anu-card \r\n        class=\"image-list-item border-round border col-sm-12 col-md-4 col-lg-4 relative\" \r\n        [style.background-image]=\"previewOnImages[imgFile.fullPath] ? 'url(\\'getImage?imageId=' + imgFile.fullPath + '\\')': 'none'\"\r\n        [class.shadow]=\"imgFile.fullPath === selectedImageFile?.fullPath\">  \r\n            <anu-card-title class=\"spacing-half image-list-item_title accent-deep-light\">\r\n                {{imgFile.name}}\r\n                <anu-spinner class=\"col-12\" [show]=\"loading?.imageFile ? loading.imageFile[imgFile?.fullPath]: false\"></anu-spinner>\r\n            </anu-card-title>\r\n            <anu-card-footer>\r\n                <div class=\"row right nowrap image-list-item_controls spacing-vertical-half spacing-horizontal\">\r\n                    <a class=\"image-list-item_control btn primary accent-deep-light\" href=\"#\" (click)=\"previewClick($event, imgFile)\" *ngIf=\"!previewOnImages[imgFile.fullPath]\" title=\"Preview\">\uD83D\uDC41</a>                    \r\n                    <a class=\"image-list-item_control btn primary accent-deep-light\" href=\"#\" (click)=\"selectClick($event, imgFile)\" *ngIf=\"imgFile.fullPath !== selectedImageFile?.fullPath\" title=\"select\">\u2714</a>\r\n                    <a class=\"image-list-item_control btn error accent-deep-light\" href=\"#\" (click)=\"deleteClick($event, imgFile)\" title=\"delete\">X</a>\r\n                </div>\r\n            </anu-card-footer>\r\n        </anu-card>\r\n    </ng-container>\r\n\r\n    <anu-card *ngIf=\"nextPageToken\" class=\"image-list-item border-round border spacing-half col-sm-12 col-md-4 col-lg-4 relative\">\r\n        <anu-card-body class=\"center center-text col-12\">\r\n            <a href=\"#\" (click)=\"loadMoreClick($event)\">Load more...</a>\r\n            <anu-spinner class=\"col-12\" [show]=\"loading.loadMore\"></anu-spinner>\r\n        </anu-card-body>        \r\n    </anu-card>\r\n    <anu-spinner class=\"col-12\" [show]=\"loading.imageFiles\"></anu-spinner>\r\n</div>\r\n\r\n<anu-modal \r\n    (okClick)=\"deleteImageOkClick()\"\r\n    (cancelClick)=\"deleteImageCancelClick()\"\r\n\t[cancelLabel]=\"'No'\"\r\n\t[enableCancel]='true'\r\n\t[enableClose]='true'\r\n\t[enableOk]='true'\r\n\t[okLabel]=\"'Yes'\"\r\n\t[opened]=\"deleteConfirmModalOpened\"\r\n\t[modalTitle]=\"'Confirm Image Deletion'\">\r\n\t<p>This will delete the image file permanently and can not be restored.</p>\r\n    <strong>Do you want to continue?</strong>\r\n</anu-modal>", styles: [":host{display:flex;flex-direction:row;flex-flow:wrap;position:relative}:host .image-list-item{background-repeat:no-repeat;background-size:cover;min-height:12rem;overflow:hidden}:host .image-list-item_controls{position:absolute;bottom:0;left:0;background-color:#0000001a}:host .image-list-item_title{background-color:#00000080;word-break:break-all}@media screen and (max-width: 767px){:host .image-list-item_control.btn{padding:.2rem .7rem}}@media screen and (min-width: 768px) and (max-width: 1023px){:host .image-list-item_control.btn{padding:.2rem .7rem}}@media screen and (min-width: 1024px){:host .image-list-item_control.btn{padding:.2rem .7rem}}:host input[type=file]{display:none}:host anu-search-box{transform:scale(.7)}\n"], dependencies: [{ kind: "directive", type: i3$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i4.CardComponent, selector: "anu-card", inputs: ["isRowLayout", "imageCssClasses", "contentCssClasses"] }, { kind: "component", type: i4.CardTitleComponent, selector: "anu-card-title" }, { kind: "component", type: i4.CardBodyComponent, selector: "anu-card-body" }, { kind: "component", type: i4.CardFooterComponent, selector: "anu-card-footer" }, { kind: "component", type: i7.ModalComponent, selector: "anu-modal", inputs: ["opened", "modalTitle", "okLabel", "cancelLabel", "enableOk", "enableCancel", "enableClose"], outputs: ["okClick", "cancelClick"] }, { kind: "component", type: i6$1.SpinnerComponent, selector: "anu-spinner", inputs: ["show", "fullscreen", "static", "size", "theme", "speed", "mode"] }, { kind: "component", type: i7$1.ErrorComponent, selector: "anu-error", inputs: ["code", "message"] }, { kind: "component", type: i8.SearchBoxComponent, selector: "anu-search-box", inputs: ["items", "keys", "placeholder"], outputs: ["changed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: ImageBrowserComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-image-browser', template: "<anu-error class=\"container\" *ngIf=\"error\" [code]=\"error?.code\" [message]=\"error?.message\"></anu-error>\r\n\r\n<div class=\"row\">\r\n    <div class=\"col-sm-12 col-md-6 col-lg-6\">\r\n        <anu-card class=\"border-round shadow spacing-half relative\">\r\n            <anu-card-title>\r\n                <h3>Upload Image</h3>\r\n            </anu-card-title>\r\n            <anu-card-body>                \r\n                <span *ngIf=\"uploadHelpText\"><small>{{uploadHelpText}}</small></span>\r\n                <div class=\"form-group container center\">\r\n                    <input #fileInput id=\"file\" type=\"file\" class=\"\" (change)=\"onFileChange($event)\" />\r\n                    <input type=\"button\" class=\"btn\" (click)=\"uploadClick()\" value=\"Choose file to upload...\">\r\n                    <input type=\"text\" class=\"spacing-around-vertical-half\" [(ngModel)]=\"choosenFileName\" placeholder=\"No image to upload\"/>\r\n                    <a class=\"btn primary spacing-around-vertical-half\" href=\"#\" (click)=\"uploadFileClick($event)\" title=\"Upload\">Upload</a>\r\n                </div>\r\n                <anu-spinner class=\"col-12\" [show]=\"loading.uploadImageFile\"></anu-spinner>\r\n            </anu-card-body>\r\n        </anu-card>\r\n    </div>\r\n    <div class=\"col-sm-12 col-md-6 col-lg-6\">\r\n        <img *ngIf=\"selectedImageFile\" class=\"selected-image shadow\" [src]=\"'getImage?imageId=' + selectedImageFile?.fullPath\" [alt]=\"selectedImageFile?.name\" />\r\n    </div>\r\n</div>\r\n\r\n\r\n<div class=\"row border center\">\r\n    <!-- Count -->\r\n    <strong>{{imagesFilesFilteredCount}} / {{imageFiles?.length || 0}}</strong>\r\n    <!-- Image Files filter -->\r\n    <anu-search-box classs=\"col-12\" [items]=\"imageFiles\" [keys]=\"['name']\"\r\n        (changed)=\"onImageListFilter($event)\"></anu-search-box>\r\n    <!-- Reload list  -->\r\n    <a class=\"spacing\" href=\"#\" (click)=\"refreshClick($event)\" title=\"Reload List\">\u27F3 Reload</a>\r\n</div>\r\n<div class=\"row border\">    \r\n    <ng-container *ngFor=\"let imgFile of imagesFilesFiltered\">\r\n        <anu-card \r\n        class=\"image-list-item border-round border col-sm-12 col-md-4 col-lg-4 relative\" \r\n        [style.background-image]=\"previewOnImages[imgFile.fullPath] ? 'url(\\'getImage?imageId=' + imgFile.fullPath + '\\')': 'none'\"\r\n        [class.shadow]=\"imgFile.fullPath === selectedImageFile?.fullPath\">  \r\n            <anu-card-title class=\"spacing-half image-list-item_title accent-deep-light\">\r\n                {{imgFile.name}}\r\n                <anu-spinner class=\"col-12\" [show]=\"loading?.imageFile ? loading.imageFile[imgFile?.fullPath]: false\"></anu-spinner>\r\n            </anu-card-title>\r\n            <anu-card-footer>\r\n                <div class=\"row right nowrap image-list-item_controls spacing-vertical-half spacing-horizontal\">\r\n                    <a class=\"image-list-item_control btn primary accent-deep-light\" href=\"#\" (click)=\"previewClick($event, imgFile)\" *ngIf=\"!previewOnImages[imgFile.fullPath]\" title=\"Preview\">\uD83D\uDC41</a>                    \r\n                    <a class=\"image-list-item_control btn primary accent-deep-light\" href=\"#\" (click)=\"selectClick($event, imgFile)\" *ngIf=\"imgFile.fullPath !== selectedImageFile?.fullPath\" title=\"select\">\u2714</a>\r\n                    <a class=\"image-list-item_control btn error accent-deep-light\" href=\"#\" (click)=\"deleteClick($event, imgFile)\" title=\"delete\">X</a>\r\n                </div>\r\n            </anu-card-footer>\r\n        </anu-card>\r\n    </ng-container>\r\n\r\n    <anu-card *ngIf=\"nextPageToken\" class=\"image-list-item border-round border spacing-half col-sm-12 col-md-4 col-lg-4 relative\">\r\n        <anu-card-body class=\"center center-text col-12\">\r\n            <a href=\"#\" (click)=\"loadMoreClick($event)\">Load more...</a>\r\n            <anu-spinner class=\"col-12\" [show]=\"loading.loadMore\"></anu-spinner>\r\n        </anu-card-body>        \r\n    </anu-card>\r\n    <anu-spinner class=\"col-12\" [show]=\"loading.imageFiles\"></anu-spinner>\r\n</div>\r\n\r\n<anu-modal \r\n    (okClick)=\"deleteImageOkClick()\"\r\n    (cancelClick)=\"deleteImageCancelClick()\"\r\n\t[cancelLabel]=\"'No'\"\r\n\t[enableCancel]='true'\r\n\t[enableClose]='true'\r\n\t[enableOk]='true'\r\n\t[okLabel]=\"'Yes'\"\r\n\t[opened]=\"deleteConfirmModalOpened\"\r\n\t[modalTitle]=\"'Confirm Image Deletion'\">\r\n\t<p>This will delete the image file permanently and can not be restored.</p>\r\n    <strong>Do you want to continue?</strong>\r\n</anu-modal>", styles: [":host{display:flex;flex-direction:row;flex-flow:wrap;position:relative}:host .image-list-item{background-repeat:no-repeat;background-size:cover;min-height:12rem;overflow:hidden}:host .image-list-item_controls{position:absolute;bottom:0;left:0;background-color:#0000001a}:host .image-list-item_title{background-color:#00000080;word-break:break-all}@media screen and (max-width: 767px){:host .image-list-item_control.btn{padding:.2rem .7rem}}@media screen and (min-width: 768px) and (max-width: 1023px){:host .image-list-item_control.btn{padding:.2rem .7rem}}@media screen and (min-width: 1024px){:host .image-list-item_control.btn{padding:.2rem .7rem}}:host input[type=file]{display:none}:host anu-search-box{transform:scale(.7)}\n"] }]
        }], ctorParameters: function () { return [{ type: ImageBrowserService }]; }, propDecorators: { fileEl: [{
                type: ViewChild,
                args: ['fileInput']
            }], imageFiles: [{
                type: Input
            }] } });

class FireStorageModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, declarations: [SitemapComponent,
            ImageBrowserComponent], imports: [CommonModule,
            FormsModule,
            CardModule,
            CollapsibleModule,
            CodeBlockModule,
            ModalModule,
            SpinnerModule,
            ErrorModule,
            SearchBoxModule], exports: [SitemapComponent,
            ImageBrowserComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, imports: [CommonModule,
            FormsModule,
            CardModule,
            CollapsibleModule,
            CodeBlockModule,
            ModalModule,
            SpinnerModule,
            ErrorModule,
            SearchBoxModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: FireStorageModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        SitemapComponent,
                        ImageBrowserComponent,
                    ],
                    providers: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        CardModule,
                        CollapsibleModule,
                        CodeBlockModule,
                        ModalModule,
                        SpinnerModule,
                        ErrorModule,
                        SearchBoxModule,
                    ],
                    exports: [
                        SitemapComponent,
                        ImageBrowserComponent,
                    ],
                }]
        }] });

class ImageFileInfo {
    constructor(imageFIle = null) {
        this.name = '';
        this.fullPath = '';
        this.downloadUrl = '';
        if (imageFIle) {
            this.name = imageFIle.name || '';
            this.fullPath = imageFIle.fullPath || '';
            this.downloadUrl = imageFIle.downloadUrl || '';
        }
    }
}

;
;
;
;

;
;

// Export all exposable angular assets from ./src folder, like components, services, pipes, directives etc.

/**
 * Generated bundle index. Do not edit.
 */

export { FireStorageImageService, FireStorageModule, FireStorageSitemapService, ImageBrowserComponent, ImageBrowserLoaderEnum, ImageBrowserService, ImageFileInfo, SitemapComponent, SitemapService, defaultSitemapXmlStr, sitemapFileName };
//# sourceMappingURL=annuadvent-ngx-tools-fire-storage.mjs.map
