import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, Injectable, NgModule } from '@angular/core';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i5 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i3 from '@annuadvent/ngx-common-ui/collapsible';
import { CollapsibleModule } from '@annuadvent/ngx-common-ui/collapsible';
import * as i6 from '@annuadvent/ngx-common-ui/spinner';
import { SpinnerModule } from '@annuadvent/ngx-common-ui/spinner';
import { Configuration, OpenAIApi, CreateImageRequestSizeEnum, CreateImageRequestResponseFormatEnum } from 'openai';
import { BehaviorSubject } from 'rxjs';
import * as i2 from '@annuadvent/ngx-tools/fire-storage';
import * as i3$1 from '@annuadvent/ngx-tools/fire-auth';
import * as i7 from '@annuadvent/ngx-common-ui/error';
import { ErrorModule } from '@annuadvent/ngx-common-ui/error';
import * as i2$1 from '@annuadvent/ngx-core/app-config';
import * as i3$2 from '@annuadvent/ngx-core/utils';
import * as i8 from '@annuadvent/ngx-common-ui/modal';
import { ModalModule } from '@annuadvent/ngx-common-ui/modal';
import * as i9 from '@annuadvent/ngx-common-ui/code-block';
import { CodeBlockModule } from '@annuadvent/ngx-common-ui/code-block';
import * as i1 from '@angular/common/http';

var OpenaiPromptTypeEnum;
(function (OpenaiPromptTypeEnum) {
    OpenaiPromptTypeEnum["keywords"] = "keywords";
    OpenaiPromptTypeEnum["subtopics"] = "subtopics";
    OpenaiPromptTypeEnum["questions"] = "questions";
    OpenaiPromptTypeEnum["description"] = "description";
    OpenaiPromptTypeEnum["content"] = "content";
    OpenaiPromptTypeEnum["image"] = "image";
})(OpenaiPromptTypeEnum || (OpenaiPromptTypeEnum = {}));
;

class OpenaiFormComponent {
    constructor() {
        this.prompts = [];
        this.selectedPromptText = '';
        this.showHistory = true;
        this.showPrompts = true;
        this.goClicked = new EventEmitter();
        this.currentPrompt = '';
        this.selectedResultType = 'mdText';
        this.promptTypes = Object.entries(OpenaiPromptTypeEnum).map((pt) => ({
            key: pt[0],
            value: pt[1],
        }));
        this.selectedPromptType = OpenaiPromptTypeEnum.content;
    }
    ngOnInit() {
        this.setSelectedPrompt();
    }
    ngOnChanges(changes) {
        this.setSelectedPrompt();
    }
    setSelectedPrompt() {
        this.selectedPrompt = this.findPrompt(this.selectedPromptText);
        this.selectedPromptType = this.selectedPrompt?.promptType || OpenaiPromptTypeEnum.content;
    }
    promptListChanged() {
        this.setSelectedPrompt();
    }
    goBtnClick(event) {
        event.preventDefault();
        if (!this.currentPrompt.trim())
            return;
        if (!this.findPrompt(this.currentPrompt)) {
            this.prompts.push({
                prompt: this.currentPrompt,
                promptType: this.selectedPromptType,
                message: { mdText: '', htmlText: '', jsonText: '' },
            });
            this.selectedPromptText = this.currentPrompt;
            this.selectedPrompt = this.findPrompt(this.selectedPromptText);
            this.currentPrompt = '';
            this.selectedPromptType = OpenaiPromptTypeEnum.content;
            this.goClicked.emit(this.prompts);
        }
    }
    findPrompt(promptStr) {
        return this.prompts.find((p) => p.prompt === promptStr);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiFormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: OpenaiFormComponent, selector: "anu-openai-form", inputs: { prompts: "prompts", selectedPromptText: "selectedPromptText", showHistory: "showHistory", showPrompts: "showPrompts" }, outputs: { goClicked: "goClicked" }, usesOnChanges: true, ngImport: i0, template: "<form class=\"container disable-select\">\r\n\r\n    <div class=\"input-container row nowrap\">\r\n        <select *ngIf=\"showPrompts\" class=\"prompt-types\" name=\"prompt-types\" [(ngModel)]=\"selectedPromptType\">\r\n            <option [value]=\"optType.value\" *ngFor=\"let optType of promptTypes\">{{optType.key}}</option>\r\n        </select>\r\n        <input name=\"openaiPrompt\" type=\"text\" placeholder=\"Write your prompt here\" [(ngModel)]=\"currentPrompt\" />\r\n        <a href=\"javascript:void(0)\" class=\"btn primary\" (click)=\"goBtnClick($event)\">\u2315</a>\r\n    </div>\r\n\r\n    <div class=\"row\" *ngIf=\"showHistory\">\r\n        <anu-collapsible [collapsed]=\"false\" class=\"col-12 spacing-around-vertical\" [hamBurgerClassNames]=\"['size-sm']\"\r\n            [isDropdownStyle]=\"true\">\r\n            <anu-collapsible-header>\r\n                Prompts History\r\n            </anu-collapsible-header>\r\n            <anu-collapsible-content class=\"row\">\r\n                <div class=\"col-6\">\r\n                    <select name=\"prompt-list\" [(ngModel)]=\"selectedPromptText\" (ngModelChange)=\"promptListChanged()\">\r\n                        <option [ngValue]=\"''\">Select..</option>\r\n                        <option [ngValue]=\"prompt.prompt\" *ngFor=\"let prompt of prompts\">{{prompt.prompt}}</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-6\">\r\n                    <select name=\"result-types\" [(ngModel)]=\"selectedResultType\">\r\n                        <option value=\"mdText\">Markdown</option>\r\n                        <option value=\"htmlText\">HTML</option>\r\n                        <option value=\"jsonText\">JSON</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-12\">\r\n                    <textarea readonly>{{selectedPrompt?.message[selectedResultType]}}</textarea>\r\n                </div>\r\n            </anu-collapsible-content>\r\n        </anu-collapsible>\r\n    </div>\r\n</form>", styles: [":host{display:flex}:host input[type=text]{border-top-left-radius:.3rem;border-bottom-left-radius:.3rem}:host .btn{border-top-left-radius:0;border-bottom-left-radius:0;font-size:2rem;color:var(--anu-accent-deep-light);margin-left:-2px;padding:0rem 1.5rem}:host .prompt-types{max-width:10rem}:host .input-container .btn{width:auto}\n"], dependencies: [{ kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i5.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i5.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i5.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i5.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i5.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i5.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i5.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i5.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i3.CollapsibleComponent, selector: "anu-collapsible", inputs: ["collapsed", "hamBurgerClassNames", "isDropdownStyle"], outputs: ["changed"] }, { kind: "component", type: i3.CollapsibleHeaderComponent, selector: "anu-collapsible-header" }, { kind: "component", type: i3.CollapsibleContentComponent, selector: "anu-collapsible-content" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-openai-form', template: "<form class=\"container disable-select\">\r\n\r\n    <div class=\"input-container row nowrap\">\r\n        <select *ngIf=\"showPrompts\" class=\"prompt-types\" name=\"prompt-types\" [(ngModel)]=\"selectedPromptType\">\r\n            <option [value]=\"optType.value\" *ngFor=\"let optType of promptTypes\">{{optType.key}}</option>\r\n        </select>\r\n        <input name=\"openaiPrompt\" type=\"text\" placeholder=\"Write your prompt here\" [(ngModel)]=\"currentPrompt\" />\r\n        <a href=\"javascript:void(0)\" class=\"btn primary\" (click)=\"goBtnClick($event)\">\u2315</a>\r\n    </div>\r\n\r\n    <div class=\"row\" *ngIf=\"showHistory\">\r\n        <anu-collapsible [collapsed]=\"false\" class=\"col-12 spacing-around-vertical\" [hamBurgerClassNames]=\"['size-sm']\"\r\n            [isDropdownStyle]=\"true\">\r\n            <anu-collapsible-header>\r\n                Prompts History\r\n            </anu-collapsible-header>\r\n            <anu-collapsible-content class=\"row\">\r\n                <div class=\"col-6\">\r\n                    <select name=\"prompt-list\" [(ngModel)]=\"selectedPromptText\" (ngModelChange)=\"promptListChanged()\">\r\n                        <option [ngValue]=\"''\">Select..</option>\r\n                        <option [ngValue]=\"prompt.prompt\" *ngFor=\"let prompt of prompts\">{{prompt.prompt}}</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-6\">\r\n                    <select name=\"result-types\" [(ngModel)]=\"selectedResultType\">\r\n                        <option value=\"mdText\">Markdown</option>\r\n                        <option value=\"htmlText\">HTML</option>\r\n                        <option value=\"jsonText\">JSON</option>\r\n                    </select>\r\n                </div>\r\n                <div class=\"col-12\">\r\n                    <textarea readonly>{{selectedPrompt?.message[selectedResultType]}}</textarea>\r\n                </div>\r\n            </anu-collapsible-content>\r\n        </anu-collapsible>\r\n    </div>\r\n</form>", styles: [":host{display:flex}:host input[type=text]{border-top-left-radius:.3rem;border-bottom-left-radius:.3rem}:host .btn{border-top-left-radius:0;border-bottom-left-radius:0;font-size:2rem;color:var(--anu-accent-deep-light);margin-left:-2px;padding:0rem 1.5rem}:host .prompt-types{max-width:10rem}:host .input-container .btn{width:auto}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { prompts: [{
                type: Input
            }], selectedPromptText: [{
                type: Input
            }], showHistory: [{
                type: Input
            }], showPrompts: [{
                type: Input
            }], goClicked: [{
                type: Output
            }] } });

;
var OpenaiImageSize;
(function (OpenaiImageSize) {
    OpenaiImageSize["_256x256"] = "256x256";
    OpenaiImageSize["_512x512"] = "512x512";
    OpenaiImageSize["_1024x1024"] = "1024x1024";
})(OpenaiImageSize || (OpenaiImageSize = {}));
;
;
;

var OpenaiConfigurationTypeEnum;
(function (OpenaiConfigurationTypeEnum) {
    OpenaiConfigurationTypeEnum["number"] = "number";
    OpenaiConfigurationTypeEnum["string"] = "string";
    OpenaiConfigurationTypeEnum["Array"] = "Array";
    OpenaiConfigurationTypeEnum["Object"] = "Object";
    OpenaiConfigurationTypeEnum["any"] = "any";
})(OpenaiConfigurationTypeEnum || (OpenaiConfigurationTypeEnum = {}));
;

const chatModel = {
    type: OpenaiConfigurationTypeEnum.string,
    value: 'gpt-3.5-turbo',
};
const audioModel = {
    type: OpenaiConfigurationTypeEnum.string,
    value: 'whisper-1',
};
const n = {
    type: OpenaiConfigurationTypeEnum.number,
    value: 1,
};
const temperature = {
    type: OpenaiConfigurationTypeEnum.number,
    value: 1,
    min: 0,
    max: 2,
    step: 0.1,
};
const messages = {
    type: OpenaiConfigurationTypeEnum.Array,
    value: [],
};
const language = {
    type: OpenaiConfigurationTypeEnum.string,
    value: 'en',
};
const prompt = {
    type: OpenaiConfigurationTypeEnum.string,
    value: '',
};
const file = {
    type: OpenaiConfigurationTypeEnum.Object,
    value: null,
};
const response_format = {
    type: OpenaiConfigurationTypeEnum.string,
    value: 'json',
    rangeValues: ['json', 'text', 'srt', 'verbose_json', 'vtt'],
};
const image_response_format = {
    type: OpenaiConfigurationTypeEnum.string,
    value: 'b64_json',
    rangeValues: ['b64_json', 'url']
};
const max_tokens = {
    type: OpenaiConfigurationTypeEnum.number,
    value: 1024,
    min: 1,
    max: 2048,
    step: 1,
};
const size = {
    type: OpenaiConfigurationTypeEnum.string,
    value: '1024x1024',
    rangeValues: ['1024x1024', '512x512', '256x256'],
};
const image = {
    type: OpenaiConfigurationTypeEnum.string,
    value: '',
};
const mask = {
    type: OpenaiConfigurationTypeEnum.string,
    value: '',
};
// CONFIG
const OPENAI_CONFIGURATION_DEFAULT = {
    baseApiUrl: {
        type: OpenaiConfigurationTypeEnum.string,
        value: 'https://api.openai.com/v1/',
    },
    apiKey: {
        type: OpenaiConfigurationTypeEnum.string,
        value: '',
    },
    cleanupKeywords: {
        type: OpenaiConfigurationTypeEnum.string,
        value: 'AI model, As an AI language model',
    },
    headers: {
        type: OpenaiConfigurationTypeEnum.Object,
        value: {
            'OpenAI-Organization': {
                type: OpenaiConfigurationTypeEnum.string,
                value: '',
            }
        },
    },
    endpoints: {
        type: OpenaiConfigurationTypeEnum.Object,
        value: {
            'models': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'data',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            response_format,
                        },
                    },
                },
            },
            'chat/completions': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'choices[].message.content',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            model: chatModel,
                            messages,
                            temperature,
                            n,
                            response_format,
                        }
                    },
                },
            },
            'completions': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'choices[].text',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            model: chatModel,
                            prompt,
                            temperature,
                            n,
                            max_tokens,
                            response_format,
                        }
                    },
                },
            },
            'images/generations': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'data.b64_json',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            prompt,
                            size,
                            n,
                            response_format: image_response_format,
                        }
                    },
                },
            },
            'images/edits': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'data.b64_json',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            image,
                            mask,
                            prompt,
                            size,
                            n,
                            response_format: image_response_format,
                        }
                    },
                },
            },
            'images/variations': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'data.b64_json',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            image,
                            prompt,
                            size,
                            n,
                            response_format: image_response_format,
                        }
                    },
                },
            },
            'audio/transcriptions': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'text',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            model: audioModel,
                            file,
                            language,
                            prompt,
                            temperature,
                            response_format,
                        }
                    },
                },
            },
            'audio/translations': {
                type: OpenaiConfigurationTypeEnum.Object,
                value: {
                    responseKey: {
                        type: OpenaiConfigurationTypeEnum.string,
                        value: 'text',
                    },
                    requestParams: {
                        type: OpenaiConfigurationTypeEnum.Object,
                        value: {
                            model: audioModel,
                            file,
                            prompt,
                            temperature,
                            response_format,
                        }
                    },
                },
            },
        },
    },
};

class OpenaiConfigService {
    constructor() {
        this.config$ = new BehaviorSubject(OPENAI_CONFIGURATION_DEFAULT);
    }
    get config() {
        return this.config$.asObservable();
    }
    get configValue() {
        return this.config$.value;
    }
    initOpenai(apiKey, organization) {
        this.config$.next(this.mergeKeyConfigWithBaseConfig(this.config$.value, { apiKey, organization }));
    }
    mergeKeyConfigWithBaseConfig(baseConfig, keyConfig) {
        const { apiKey, organization } = keyConfig;
        return {
            ...baseConfig,
            apiKey: {
                ...baseConfig.apiKey,
                value: apiKey
            },
            headers: {
                ...baseConfig.headers,
                value: {
                    ...baseConfig.headers.value,
                    'OpenAI-Organization': {
                        ...baseConfig.headers.value['OpenAI-Organization'],
                        value: organization,
                    },
                }
            }
        };
    }
    getKeyConfig(config) {
        const openaiConfig = {
            apiKey: config?.apiKey?.value,
            organization: config?.headers?.value['OpenAI-Organization'].value,
        };
        return openaiConfig;
    }
    updateConfig(config) {
        this.config$.next(config);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiConfigService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class OpenaiService {
    constructor(openaiConfigService) {
        this.openaiConfigService = openaiConfigService;
        this.openaiConfigService.config.subscribe(config => {
            this.initOpenai(this.openaiConfigService.getKeyConfig(config));
        });
    }
    initOpenai(openaiConfig) {
        if (!openaiConfig || !openaiConfig.apiKey || !openaiConfig.organization)
            throw new Error('Invalid openai configuration.');
        this.openaiConfig = { ...openaiConfig };
        const { apiKey, organization } = this.openaiConfig;
        const configuration = new Configuration({
            organization,
            apiKey,
        });
        delete configuration.baseOptions.headers['User-Agent'];
        this.openAi = null;
        this.openAi = new OpenAIApi(configuration);
    }
    async getChatResponse(prompts) {
        if (!this.openAi)
            throw new Error('Openai is not initialzed. Use initOpenai(openaiConfig) to initialize');
        if (!prompts || !prompts.length)
            throw new Error('Not a valid Prompt. Provide one or more prompts in an array of strings.');
        const messages = prompts.map((p) => ({ role: 'user', content: p }));
        const req = {
            model: 'gpt-3.5-turbo',
            messages,
            temperature: 0.7,
            n: 1,
        };
        const response = await this.openAi.createChatCompletion(req);
        const resultMessages = response.data?.choices || [];
        const msgContents = resultMessages.map((rmChoices) => rmChoices.message?.content);
        return msgContents.join('\n');
    }
    async getImagetResponse(promptText, imagesCount = 1, imageSize) {
        if (!this.openAi)
            throw new Error('Openai is not initialzed. Use initOpenai(openaiConfig) to initialize');
        if (!promptText)
            throw new Error('Not a valid Image Prompt.');
        const req = {
            prompt: promptText,
            n: imagesCount || 1,
            size: imageSize || CreateImageRequestSizeEnum._1024x1024,
            response_format: CreateImageRequestResponseFormatEnum.B64Json,
        };
        const response = await this.openAi.createImage(req);
        const imagesData = response.data?.data || [];
        const base64Images = imagesData.map((data) => data.b64_json || '');
        return base64Images;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiService, deps: [{ token: OpenaiConfigService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: OpenaiConfigService }]; } });

class OpenaiImageFormComponent {
    constructor(openaiService, fireStorageImageService, fireAuthService) {
        this.openaiService = openaiService;
        this.fireStorageImageService = fireStorageImageService;
        this.fireAuthService = fireAuthService;
        this.imagePromptText = '';
        this.imageFileName = '';
        this.imageGenerated = new EventEmitter();
        this.fileUploaded = new EventEmitter();
        this.generatedBase64Image = '';
        this.savedImageUrl = '';
        this.loading = false;
        this.errorMsg = '';
    }
    async generateImage() {
        if (!this.imagePromptText.trim())
            return '';
        this.startLoading();
        try {
            [this.generatedBase64Image] = await this.openaiService.getImagetResponse(this.imagePromptText, 1, OpenaiImageSize._1024x1024);
            this.stopLoading();
            this.imageGenerated.emit(this.generatedBase64Image);
            return this.generatedBase64Image;
        }
        catch (err) {
            this.generatedBase64Image = '';
            this.stopLoading(err?.message);
            this.imageGenerated.emit('');
            return '';
        }
    }
    async uploadImage() {
        this.startLoading();
        if (!this.generatedBase64Image || !this.imageFileName) {
            this.stopLoading('Empty Image or not a valid file name');
            return;
        }
        const userId = this.fireAuthService.getCurrentUserId();
        if (!userId) {
            this.stopLoading('User is not authenticated or logged in.');
            return;
        }
        try {
            const imageFileInfo = await this.fireStorageImageService.uploadImage(this.imageFileName, this.generatedBase64Image, true, userId, true);
            this.generatedBase64Image = '';
            this.savedImageUrl = `getImage?imageId=${imageFileInfo.fullPath}`;
            this.fileUploaded.emit(imageFileInfo);
            this.stopLoading();
            return;
        }
        catch (err) {
            this.stopLoading(err.message);
            return;
        }
    }
    startLoading() {
        this.loading = true;
        this.errorMsg = '';
    }
    stopLoading(err = '') {
        this.loading = false;
        this.errorMsg = err;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiImageFormComponent, deps: [{ token: OpenaiService }, { token: i2.FireStorageImageService }, { token: i3$1.FireAuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: OpenaiImageFormComponent, selector: "anu-openai-image-form", inputs: { imagePromptText: "imagePromptText", imageFileName: "imageFileName" }, outputs: { imageGenerated: "imageGenerated", fileUploaded: "fileUploaded" }, ngImport: i0, template: "<anu-error *ngIf=\"errorMsg\" code=\"UNKNOWN\" [message]=\"errorMsg\"></anu-error>\r\n<form class=\"container relative disable-select\">\r\n    <label>Image Prompt</label>\r\n    <input type=\"text\" [(ngModel)]=\"imagePromptText\" name=\"imagePromptText\" />\r\n    <label>Image file name to save generated image<small class=\"error\">* Any image with this filename will be\r\n            overwritten in your image library.</small></label>\r\n    <input type=\"text\" [(ngModel)]=\"imageFileName\" name=\"imageFileName\" />\r\n    <div *ngIf=\"!!generatedBase64Image\" class=\"row\">\r\n        <label>Generated Image <a class=\"primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generatedBase64Image = ''\">Clear</a></label>\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"'data:image/image/jpg;base64,'+ generatedBase64Image\" />\r\n    </div>\r\n    <div *ngIf=\"savedImageUrl\" class=\"row\">\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"savedImageUrl\" />\r\n    </div>\r\n\r\n    <p *ngIf=\"errorMsg\">{{errorMsg}}</p>\r\n    <div class=\"row spacing\">\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generateImage()\">Generate</a></div>\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\" (click)=\"uploadImage()\">Upload</a>\r\n        </div>\r\n    </div>\r\n    <anu-spinner [show]=\"loading\"></anu-spinner>\r\n</form>\r\n", styles: [":host .oif_image{width:100%}\n"], dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i5.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i5.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i5.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i5.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i5.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i6.SpinnerComponent, selector: "anu-spinner", inputs: ["show", "fullscreen", "static", "size", "theme", "speed", "mode"] }, { kind: "component", type: i7.ErrorComponent, selector: "anu-error", inputs: ["code", "message"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiImageFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-openai-image-form', template: "<anu-error *ngIf=\"errorMsg\" code=\"UNKNOWN\" [message]=\"errorMsg\"></anu-error>\r\n<form class=\"container relative disable-select\">\r\n    <label>Image Prompt</label>\r\n    <input type=\"text\" [(ngModel)]=\"imagePromptText\" name=\"imagePromptText\" />\r\n    <label>Image file name to save generated image<small class=\"error\">* Any image with this filename will be\r\n            overwritten in your image library.</small></label>\r\n    <input type=\"text\" [(ngModel)]=\"imageFileName\" name=\"imageFileName\" />\r\n    <div *ngIf=\"!!generatedBase64Image\" class=\"row\">\r\n        <label>Generated Image <a class=\"primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generatedBase64Image = ''\">Clear</a></label>\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"'data:image/image/jpg;base64,'+ generatedBase64Image\" />\r\n    </div>\r\n    <div *ngIf=\"savedImageUrl\" class=\"row\">\r\n        <img class=\"oif_image spacing-around-vertical\" [src]=\"savedImageUrl\" />\r\n    </div>\r\n\r\n    <p *ngIf=\"errorMsg\">{{errorMsg}}</p>\r\n    <div class=\"row spacing\">\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\"\r\n                (click)=\"generateImage()\">Generate</a></div>\r\n        <div class=\"col-6 center\"><a class=\"btn primary\" href=\"javascript:void(0)\" (click)=\"uploadImage()\">Upload</a>\r\n        </div>\r\n    </div>\r\n    <anu-spinner [show]=\"loading\"></anu-spinner>\r\n</form>\r\n", styles: [":host .oif_image{width:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: OpenaiService }, { type: i2.FireStorageImageService }, { type: i3$1.FireAuthService }]; }, propDecorators: { imagePromptText: [{
                type: Input
            }], imageFileName: [{
                type: Input
            }], imageGenerated: [{
                type: Output
            }], fileUploaded: [{
                type: Output
            }] } });

class OpenaiConfigurationComponent {
    constructor(openaiConfigService, appConfigService, utilsService) {
        this.openaiConfigService = openaiConfigService;
        this.appConfigService = appConfigService;
        this.utilsService = utilsService;
        this.config = null;
        this.showLoadFromJsonModal = false;
        this.fromJsonConfigStr = '';
        this.fromJsonErrorMsg = '';
        // Subscribe to openai config change
        this.openaiConfigService.config.subscribe((config) => {
            this.config = this.utilsService.deepCopy(config);
        });
    }
    updateClicked(event) {
        event.preventDefault();
        this.openaiConfigService.updateConfig(this.utilsService.deepCopy(this.config));
    }
    loadDefault(event) {
        event.preventDefault();
        this.config = this.openaiConfigService.mergeKeyConfigWithBaseConfig(this.utilsService.deepCopy(OPENAI_CONFIGURATION_DEFAULT), this.appConfigService.openai);
    }
    loadFromJsonClicked(event) {
        event.preventDefault();
        this.fromJsonErrorMsg = '';
        this.fromJsonConfigStr = JSON.stringify(this.config || {}, null, '\t');
        this.showLoadFromJsonModal = true;
    }
    loadFromJsonOkClicked(event) {
        this.showLoadFromJsonModal = false;
        try {
            this.config = JSON.parse(this.fromJsonConfigStr);
            this.showLoadFromJsonModal = false;
        }
        catch (err) {
            this.fromJsonErrorMsg = err.message || err.text || err.toString() || 'something is wrong with the json';
            setTimeout(() => this.showLoadFromJsonModal = true);
        }
    }
    loadFromJsonCancelClicked(event) {
        this.showLoadFromJsonModal = false;
    }
    fromJsonConfigStrChanged(codeBlockInfo) {
        this.fromJsonConfigStr = codeBlockInfo.source;
    }
    getTypeOfKey(value) {
        return (typeof value);
    }
    getObjectKeys(value) {
        if (typeof value === 'object' && value) {
            return Object.keys(value);
        }
        return [];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiConfigurationComponent, deps: [{ token: OpenaiConfigService }, { token: i2$1.AppConfigService }, { token: i3$2.UtilsService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: OpenaiConfigurationComponent, selector: "anu-openai-configuration", ngImport: i0, template: "<div class=\"row right\">\n    <a class=\"btn primary\" (click)=\"loadFromJsonClicked($event)\">Load From Json</a>\n    <a class=\"btn primary\" (click)=\"loadDefault($event)\">Load Default</a>\n    <a class=\"btn primary\" (click)=\"updateClicked($event)\">Update</a>\n</div>\n\n<div class=\"container\" *ngFor=\"let cKey of getObjectKeys(config)\">\n    <ng-container *ngTemplateOutlet=\"tree;context:{itemKey: cKey, item: config[cKey]}\"></ng-container>\n</div>\n\n\n<ng-template #tree let-item=\"item\" let-itemKey=\"itemKey\">\n    <ng-container *ngIf=\"item\">\n        <div class=\"row\" *ngIf=\"item.type === 'string'\">\n            <label>{{itemKey}}</label>\n            <input *ngIf=\"!item.rangeValues?.length\" type=\"text\" [(ngModel)]=\"item.value\" [placeholder]=\"itemKey\" />\n            <select *ngIf=\"item.rangeValues?.length\" [(ngModel)]=\"item.value\">\n                <option [value]=\"rItem\" *ngFor=\"let rItem of item.rangeValues\">{{rItem}}</option>\n            </select>\n        </div>\n        <div class=\"row\" *ngIf=\"item.type === 'number'\">\n            <label>{{itemKey}}</label>\n\n            <div class=\"row stretch range-container relative\" *ngIf=\"item.min || item.max\">\n                <span class=\"range-min\">{{item.min}}</span>\n                <small class=\"range-value\">{{item.value}}</small>\n                <input class=\"container\" type=\"range\" [step]=\"item.step || 1\" [min]=\"item.min\" [max]=\"item.max\"\n                    [title]=\"item.value\" [(ngModel)]=\"item.value\" />\n                <span class=\"range-max\">{{item.max}}</span>\n            </div>\n            <input *ngIf=\"!item.min && !item.max\" type=\"number\" [(ngModel)]=\"item.value\" />\n        </div>\n\n\n        <anu-collapsible class=\"container border-round spacing-around-vertical\" *ngIf=\"item.type === 'Object'\"\n            [collapsed]=\"false\"\n            [hamBurgerClassNames]=\"['size-sm', 'primary-dark-grad', 'border-round', 'spacing-half', 'accent-deep-light']\"\n            [isDropdownStyle]=\"false\">\n            <anu-collapsible-header class=\"\">\n                <strong class=\"accent-deep-light\">{{itemKey}}</strong>\n            </anu-collapsible-header>\n            <anu-collapsible-content class=\"container\">\n                <div class=\"container group-container\" *ngFor=\"let cKey of getObjectKeys(item.value)\">\n                    <ng-container\n                        *ngTemplateOutlet=\"tree;context:{itemKey: cKey, item: item.value[cKey]}\"></ng-container>\n                </div>\n            </anu-collapsible-content>\n        </anu-collapsible>\n    </ng-container>\n    <anu-error *ngIf=\"!item\" code=\"UNKNOWN\" message=\"No Config Item available\"></anu-error>\n</ng-template>\n\n\n<anu-modal (cancelClick)=\"loadFromJsonCancelClicked($event)\" (okClick)=\"loadFromJsonOkClicked($event)\"\n    [cancelLabel]=\"'Cancel'\" [enableCancel]=\"true\" [enableClose]=\"true\" [enableOk]=\"true\" [okLabel]=\"'Ok'\"\n    [opened]=\"showLoadFromJsonModal\" [title]=\"'Load Configuration from Json'\">\n\n    <anu-code-block (changed)=\"fromJsonConfigStrChanged($event)\" [enableEdit]=\"true\" [language]=\"'json'\"\n        [source]='fromJsonConfigStr'>\n    </anu-code-block>\n    <anu-error *ngIf=\"fromJsonErrorMsg\" code=\"JSON_PARSE_ERROR\" [message]=\"fromJsonErrorMsg\"></anu-error>\n</anu-modal>", styles: [":host anu-collapsible{border-left:1px solid var(--anu-primary-dark)}:host .group-container{padding:var(--anu-spacing);padding-right:0}:host .range-container{padding-left:1.5rem;padding-right:2.5rem;height:2.2rem;align-items:flex-start}:host .range-container>span{position:absolute;top:-.4rem}:host .range-container>span.range-min{left:0}:host .range-container>span.range-max{right:0}:host .range-container .range-value{position:absolute;left:50%;bottom:0;z-index:-1}\n"], dependencies: [{ kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i4.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i5.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i5.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i5.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i5.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i5.RangeValueAccessor, selector: "input[type=range][formControlName],input[type=range][formControl],input[type=range][ngModel]" }, { kind: "directive", type: i5.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i5.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.CollapsibleComponent, selector: "anu-collapsible", inputs: ["collapsed", "hamBurgerClassNames", "isDropdownStyle"], outputs: ["changed"] }, { kind: "component", type: i3.CollapsibleHeaderComponent, selector: "anu-collapsible-header" }, { kind: "component", type: i3.CollapsibleContentComponent, selector: "anu-collapsible-content" }, { kind: "component", type: i7.ErrorComponent, selector: "anu-error", inputs: ["code", "message"] }, { kind: "component", type: i8.ModalComponent, selector: "anu-modal", inputs: ["opened", "modalTitle", "okLabel", "cancelLabel", "enableOk", "enableCancel", "enableClose"], outputs: ["okClick", "cancelClick"] }, { kind: "component", type: i9.CodeBlockComponent, selector: "anu-code-block", inputs: ["source", "language", "enableEdit"], outputs: ["changed", "sourceModalOpenStatusChanged"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiConfigurationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-openai-configuration', template: "<div class=\"row right\">\n    <a class=\"btn primary\" (click)=\"loadFromJsonClicked($event)\">Load From Json</a>\n    <a class=\"btn primary\" (click)=\"loadDefault($event)\">Load Default</a>\n    <a class=\"btn primary\" (click)=\"updateClicked($event)\">Update</a>\n</div>\n\n<div class=\"container\" *ngFor=\"let cKey of getObjectKeys(config)\">\n    <ng-container *ngTemplateOutlet=\"tree;context:{itemKey: cKey, item: config[cKey]}\"></ng-container>\n</div>\n\n\n<ng-template #tree let-item=\"item\" let-itemKey=\"itemKey\">\n    <ng-container *ngIf=\"item\">\n        <div class=\"row\" *ngIf=\"item.type === 'string'\">\n            <label>{{itemKey}}</label>\n            <input *ngIf=\"!item.rangeValues?.length\" type=\"text\" [(ngModel)]=\"item.value\" [placeholder]=\"itemKey\" />\n            <select *ngIf=\"item.rangeValues?.length\" [(ngModel)]=\"item.value\">\n                <option [value]=\"rItem\" *ngFor=\"let rItem of item.rangeValues\">{{rItem}}</option>\n            </select>\n        </div>\n        <div class=\"row\" *ngIf=\"item.type === 'number'\">\n            <label>{{itemKey}}</label>\n\n            <div class=\"row stretch range-container relative\" *ngIf=\"item.min || item.max\">\n                <span class=\"range-min\">{{item.min}}</span>\n                <small class=\"range-value\">{{item.value}}</small>\n                <input class=\"container\" type=\"range\" [step]=\"item.step || 1\" [min]=\"item.min\" [max]=\"item.max\"\n                    [title]=\"item.value\" [(ngModel)]=\"item.value\" />\n                <span class=\"range-max\">{{item.max}}</span>\n            </div>\n            <input *ngIf=\"!item.min && !item.max\" type=\"number\" [(ngModel)]=\"item.value\" />\n        </div>\n\n\n        <anu-collapsible class=\"container border-round spacing-around-vertical\" *ngIf=\"item.type === 'Object'\"\n            [collapsed]=\"false\"\n            [hamBurgerClassNames]=\"['size-sm', 'primary-dark-grad', 'border-round', 'spacing-half', 'accent-deep-light']\"\n            [isDropdownStyle]=\"false\">\n            <anu-collapsible-header class=\"\">\n                <strong class=\"accent-deep-light\">{{itemKey}}</strong>\n            </anu-collapsible-header>\n            <anu-collapsible-content class=\"container\">\n                <div class=\"container group-container\" *ngFor=\"let cKey of getObjectKeys(item.value)\">\n                    <ng-container\n                        *ngTemplateOutlet=\"tree;context:{itemKey: cKey, item: item.value[cKey]}\"></ng-container>\n                </div>\n            </anu-collapsible-content>\n        </anu-collapsible>\n    </ng-container>\n    <anu-error *ngIf=\"!item\" code=\"UNKNOWN\" message=\"No Config Item available\"></anu-error>\n</ng-template>\n\n\n<anu-modal (cancelClick)=\"loadFromJsonCancelClicked($event)\" (okClick)=\"loadFromJsonOkClicked($event)\"\n    [cancelLabel]=\"'Cancel'\" [enableCancel]=\"true\" [enableClose]=\"true\" [enableOk]=\"true\" [okLabel]=\"'Ok'\"\n    [opened]=\"showLoadFromJsonModal\" [title]=\"'Load Configuration from Json'\">\n\n    <anu-code-block (changed)=\"fromJsonConfigStrChanged($event)\" [enableEdit]=\"true\" [language]=\"'json'\"\n        [source]='fromJsonConfigStr'>\n    </anu-code-block>\n    <anu-error *ngIf=\"fromJsonErrorMsg\" code=\"JSON_PARSE_ERROR\" [message]=\"fromJsonErrorMsg\"></anu-error>\n</anu-modal>", styles: [":host anu-collapsible{border-left:1px solid var(--anu-primary-dark)}:host .group-container{padding:var(--anu-spacing);padding-right:0}:host .range-container{padding-left:1.5rem;padding-right:2.5rem;height:2.2rem;align-items:flex-start}:host .range-container>span{position:absolute;top:-.4rem}:host .range-container>span.range-min{left:0}:host .range-container>span.range-max{right:0}:host .range-container .range-value{position:absolute;left:50%;bottom:0;z-index:-1}\n"] }]
        }], ctorParameters: function () { return [{ type: OpenaiConfigService }, { type: i2$1.AppConfigService }, { type: i3$2.UtilsService }]; } });

class OpenaiModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, declarations: [OpenaiFormComponent, OpenaiImageFormComponent, OpenaiConfigurationComponent], imports: [CommonModule,
            FormsModule,
            CollapsibleModule,
            SpinnerModule,
            ErrorModule,
            ModalModule,
            CodeBlockModule], exports: [OpenaiFormComponent, OpenaiImageFormComponent, OpenaiConfigurationComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, imports: [CommonModule,
            FormsModule,
            CollapsibleModule,
            SpinnerModule,
            ErrorModule,
            ModalModule,
            CodeBlockModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [OpenaiFormComponent, OpenaiImageFormComponent, OpenaiConfigurationComponent],
                    providers: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        CollapsibleModule,
                        SpinnerModule,
                        ErrorModule,
                        ModalModule,
                        CodeBlockModule,
                    ],
                    exports: [OpenaiFormComponent, OpenaiImageFormComponent, OpenaiConfigurationComponent],
                }]
        }] });

const OPENAI_ID_PHRASES = ['AI model', 'As an AI language model']; // TODO: to be deled

;
;

/**
 * TODO: inprogress
 */
class OpenaiHttpService {
    constructor(httpClient, openaiConfigurationService) {
        this.httpClient = httpClient;
        this.openaiConfigurationService = openaiConfigurationService;
        this.openaiConfiguration = null;
        this.openaiConfigurationService.config.subscribe(config => this.openaiConfiguration = config);
    }
    getOpenaiEndpointResult(endpoint) {
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiHttpService, deps: [{ token: i1.HttpClient }, { token: OpenaiConfigService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiHttpService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: OpenaiHttpService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }, { type: OpenaiConfigService }]; } });

// Export all exposable angular assets from ./src folder, like components, services, pipes, directives etc.

/**
 * Generated bundle index. Do not edit.
 */

export { OPENAI_CONFIGURATION_DEFAULT, OPENAI_ID_PHRASES, OpenaiConfigService, OpenaiConfigurationComponent, OpenaiConfigurationTypeEnum, OpenaiFormComponent, OpenaiHttpService, OpenaiImageFormComponent, OpenaiImageSize, OpenaiModule, OpenaiPromptTypeEnum, OpenaiService };
//# sourceMappingURL=annuadvent-ngx-tools-openai.mjs.map
