import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { BehaviorSubject } from 'rxjs';

var QueueStatusEnum;
(function (QueueStatusEnum) {
    QueueStatusEnum["notstarted"] = "notstarted";
    QueueStatusEnum["inprogress"] = "inprogress";
    QueueStatusEnum["completed"] = "completed";
    QueueStatusEnum["failed"] = "failed";
    QueueStatusEnum["paused"] = "paused";
})(QueueStatusEnum || (QueueStatusEnum = {}));
;

/**
 * Visualizes the Queue running status, with counts and status for inprogress, paused, notstarted, failed and completeed.
 */
class QueueStatusComponent {
    constructor() {
        this.queue = null;
        this.startClick = new EventEmitter();
        this.qItems = [];
        this.qStatus = QueueStatusEnum.notstarted;
        this.totalCount = 0;
        this.completedCount = 0;
        this.notstartedCount = 0;
        this.failedCount = 0;
        this.inprogressCount = 0;
        this.queueSubscription = null;
        this.statusSubscription = null;
        this.timerSubscription = null;
        this.timeEllapsed = 0;
    }
    ngOnInit() {
        this.subscribeQueue();
    }
    ngOnChanges(changes) {
        this.subscribeQueue();
    }
    ngOnDestroy() {
        // Unsubscribe if already subscribed
        this.queueSubscription && this.queueSubscription.unsubscribe();
        this.statusSubscription && this.statusSubscription.unsubscribe();
        this.timerSubscription && this.timerSubscription.unsubscribe();
    }
    subscribeQueue() {
        if (!this.queue)
            return;
        // Unsubscribe if already subscribed
        this.queueSubscription && this.queueSubscription.unsubscribe();
        this.statusSubscription && this.statusSubscription.unsubscribe();
        this.timerSubscription && this.timerSubscription.unsubscribe();
        // Subscribe queue items change
        this.queue?.queue?.subscribe((qItems) => {
            this.qItems = qItems;
            this.refreshQueueCounters();
        });
        // Subscribe queue status change
        this.queue?.status?.subscribe((status) => this.qStatus = status);
        // Subscribe timer
        this.queue?.timer?.subscribe((timeStarted) => this.timeEllapsed = timeStarted ? Math.round((Date.now() - timeStarted) / 1000) : 0);
    }
    refreshQueueCounters() {
        this.totalCount = this.qItems?.length || 0;
        this.completedCount = 0;
        this.notstartedCount = 0;
        this.failedCount = 0;
        this.inprogressCount = 0;
        // Calculate counters by cheching all items
        this.qItems.map(qItem => {
            switch (qItem.status) {
                case QueueStatusEnum.notstarted:
                    this.notstartedCount++;
                    break;
                case QueueStatusEnum.inprogress:
                    this.inprogressCount++;
                    break;
                case QueueStatusEnum.completed:
                    this.completedCount++;
                    break;
                case QueueStatusEnum.failed:
                    this.failedCount++;
                    break;
            }
        });
    }
    startClicked(event) {
        switch (this.qStatus) {
            case QueueStatusEnum.notstarted:
                this.startClick.emit(event);
                break;
            case QueueStatusEnum.inprogress:
                this.queue?.pause();
                break;
            case QueueStatusEnum.paused:
                this.queue?.resume();
                break;
            default:
                console.log('Queue is complted or stopped already Or may be not initialized yet.');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: QueueStatusComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.0", type: QueueStatusComponent, selector: "anu-queue-status", inputs: { queue: "queue" }, outputs: { startClick: "startClick" }, usesOnChanges: true, ngImport: i0, template: "<div title=\"Total\" class=\"text-center accent-deep-light spacing-around-half queue_badge\">\n    {{totalCount}}</div>\n<div title=\"notstarted\" class=\"text-center accent-deep-light spacing-around-half queue_badge notstarted\">\n    {{notstartedCount}}</div>\n<div title=\"completed\" class=\"text-center accent-deep-light spacing-around-half queue_badge completed\">\n    {{completedCount}}</div>\n<div title=\"inprogress\" class=\"text-center accent-deep-light spacing-around-half queue_badge inprogress\">\n    {{inprogressCount}}</div>\n<div title=\"failed\" class=\"text-center accent-deep-light spacing-around-half queue_badge failed\">{{failedCount}}</div>\n<div [ngClass]=\"qStatus\" [title]=\"qStatus\" class=\"text-center accent-deep-light spacing-around-half queue_badge\">\n    <a href=\"javascript:void(0)\" (click)=\"startClicked($event)\">{{ qStatus === 'inprogress' ? '\u23F8' : '\u23F5'}}</a>\n</div>\n<div title=\"timer\" class=\"text-center accent-deep-light spacing-around-half queue_badge timer\">{{timeEllapsed}}s</div>\n<ng-content></ng-content>", styles: [":host .queue_badge{border-radius:50%;width:2em;height:2em;line-height:2em;background-color:#a200d780}:host .queue_badge.notstarted{background-color:#7c7c7ca6}:host .queue_badge.completed{background-color:#1979008c}:host .queue_badge.inprogress{background-color:#00ee0c80}:host .queue_badge.failed{background-color:#eb000080}:host .queue_badge.paused{background-color:#0ebbff88}:host .queue_badge.timer{border-radius:.5rem;width:4em}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: QueueStatusComponent, decorators: [{
            type: Component,
            args: [{ selector: 'anu-queue-status', template: "<div title=\"Total\" class=\"text-center accent-deep-light spacing-around-half queue_badge\">\n    {{totalCount}}</div>\n<div title=\"notstarted\" class=\"text-center accent-deep-light spacing-around-half queue_badge notstarted\">\n    {{notstartedCount}}</div>\n<div title=\"completed\" class=\"text-center accent-deep-light spacing-around-half queue_badge completed\">\n    {{completedCount}}</div>\n<div title=\"inprogress\" class=\"text-center accent-deep-light spacing-around-half queue_badge inprogress\">\n    {{inprogressCount}}</div>\n<div title=\"failed\" class=\"text-center accent-deep-light spacing-around-half queue_badge failed\">{{failedCount}}</div>\n<div [ngClass]=\"qStatus\" [title]=\"qStatus\" class=\"text-center accent-deep-light spacing-around-half queue_badge\">\n    <a href=\"javascript:void(0)\" (click)=\"startClicked($event)\">{{ qStatus === 'inprogress' ? '\u23F8' : '\u23F5'}}</a>\n</div>\n<div title=\"timer\" class=\"text-center accent-deep-light spacing-around-half queue_badge timer\">{{timeEllapsed}}s</div>\n<ng-content></ng-content>", styles: [":host .queue_badge{border-radius:50%;width:2em;height:2em;line-height:2em;background-color:#a200d780}:host .queue_badge.notstarted{background-color:#7c7c7ca6}:host .queue_badge.completed{background-color:#1979008c}:host .queue_badge.inprogress{background-color:#00ee0c80}:host .queue_badge.failed{background-color:#eb000080}:host .queue_badge.paused{background-color:#0ebbff88}:host .queue_badge.timer{border-radius:.5rem;width:4em}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { queue: [{
                type: Input
            }], startClick: [{
                type: Output
            }] } });

class QueueModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: QueueModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.0", ngImport: i0, type: QueueModule, declarations: [QueueStatusComponent], imports: [CommonModule], exports: [QueueStatusComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: QueueModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.0", ngImport: i0, type: QueueModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        QueueStatusComponent
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [
                        QueueStatusComponent
                    ],
                }]
        }] });

class QueueItem {
    constructor(idOrQueueItem = '', data = null, status = QueueStatusEnum.notstarted, startTime = 0, completedTime = 0) {
        this.id = '';
        this.status = QueueStatusEnum.notstarted;
        this.startTime = 0;
        this.completedTime = 0;
        if (!idOrQueueItem)
            return;
        if (typeof idOrQueueItem === 'string') {
            // if id is provided, then fill oitem with rest of the params
            this.id = idOrQueueItem;
            this.data = data;
            this.status = status;
            this.startTime = startTime;
            this.completedTime = completedTime;
        }
        else {
            // if QueueItem object is provided, then ignore other params, and fill from object
            const { id, data, status, startTime, completedTime } = idOrQueueItem;
            this.id = id;
            this.data = data;
            this.status = status;
            this.startTime = startTime;
            this.completedTime = completedTime;
        }
    }
    get timeEllapsed() {
        if (this.startTime === 0)
            return 0;
        return Math.round((this.completedTime > 0 ?
            this.completedTime - this.startTime :
            Date.now() - this.startTime) / 1000);
    }
    start() {
        this.status = QueueStatusEnum.inprogress;
        this.startTime = Date.now();
    }
    complete() {
        this.status = QueueStatusEnum.completed;
        this.completedTime = Date.now();
    }
    fail() {
        this.status = QueueStatusEnum.failed;
        this.completedTime = Date.now();
    }
}

class Queue {
    constructor() {
        this.startTime = 0;
        this.batchSize = 0;
        this.minBatchTime = 0;
        this.failedDelay = 0;
        this.batchStartTime = 0;
        this.interval = null;
        // Init Subjects
        this.queue$ = new BehaviorSubject([]);
        this.currentBatch$ = new BehaviorSubject([]);
        this.status$ = new BehaviorSubject(QueueStatusEnum.notstarted);
        this.timer$ = new BehaviorSubject(0);
    }
    // Subjects public Value getters
    get queueValue() {
        return this.queue$.value;
    }
    get currentBatchValue() {
        return this.currentBatch$.value;
    }
    get statusValue() {
        return this.status$.value;
    }
    get timerValue() {
        return this.timer$.value;
    }
    // Subjects Value getters as observables
    get queue() {
        return this.queue$.asObservable();
    }
    get currentBatch() {
        return this.currentBatch$.asObservable();
    }
    get status() {
        return this.status$.asObservable();
    }
    get timer() {
        return this.timer$.asObservable();
    }
    // private methods
    getUniqueFromString(str = '') {
        const rndStr = Math.random().toString(36).substring(2);
        const uniqueId = Date.now().toString(36) + rndStr.substring(rndStr.length / 3);
        return `${str}-${uniqueId}`;
    }
    find(id) {
        return this.queue$.value.find(item => item.id === id);
    }
    // private canMethods
    canAdd(item) {
        const isExist = this.find(item?.id);
        return !!(item &&
            item.id &&
            !isExist &&
            item.status === QueueStatusEnum.notstarted);
    }
    canRemove(item) {
        const isExist = this.find(item?.id);
        return !!(item &&
            item.id &&
            isExist &&
            item.status === QueueStatusEnum.notstarted);
    }
    canUpdate(item) {
        const isExist = this.find(item?.id);
        return !!(item &&
            item.id &&
            isExist && // Update is allowed on existing item only
            isExist.status !== QueueStatusEnum.completed && // if already completed, no change allowed
            item.status !== QueueStatusEnum.notstarted // Can not reset item to notstarted, once added to queue(as notstarted already)
        );
    }
    canClear() {
        return [
            QueueStatusEnum.notstarted,
            QueueStatusEnum.completed,
        ].includes(this.statusValue);
    }
    canStart() {
        return this.statusValue === QueueStatusEnum.notstarted;
    }
    canPause() {
        return this.statusValue === QueueStatusEnum.inprogress;
    }
    canResume() {
        return [
            QueueStatusEnum.paused,
            QueueStatusEnum.completed, // completed can also be resumed, assuming some items are added later, if still empty, will be paused again.
        ].includes(this.statusValue);
    }
    canNotifyCurrentItems() {
        // If any of the items are inprogress, that means current batch is not completed yet.
        // So need not to emit next batch
        return this.statusValue === QueueStatusEnum.inprogress && !this.queueValue.find(item => item.status === QueueStatusEnum.inprogress);
    }
    // private Notify change in subjects methods.
    notifyQueueChange(items) {
        const qItems = items.map(item => new QueueItem(item));
        this.queue$.next(qItems);
    }
    notifyBatchAndQueue(batch) {
        const statusUpdatedItems = this.queueValue.map(item => {
            const match = batch.find(it => it.id === item.id);
            match && match.start();
            return match || item;
        });
        this.batchStartTime = Date.now();
        this.currentBatch$.next(batch);
        this.notifyQueueChange(statusUpdatedItems);
    }
    notifyStatusChange(status) {
        this.status$.next(status);
        if (status === QueueStatusEnum.inprogress) {
            this.notifyCurrentBatchChange();
        }
    }
    notifyCurrentBatchChange(clear = false) {
        if (clear) {
            this.currentBatch$.next([]);
            return;
        }
        if (this.canNotifyCurrentItems()) {
            const nextItems = this.getNextCurrentItems();
            if (!nextItems?.length) {
                // pause queue, if all items are processed.
                this.pause();
            }
            else if (this.batchStartTime === 0) {
                this.notifyBatchAndQueue(nextItems);
            }
            else {
                const batchHasFailedItem = nextItems.find(item => item.status === QueueStatusEnum.failed);
                const batchEllapsedTime = Date.now() - this.batchStartTime;
                let delayTime = this.minBatchTime - batchEllapsedTime;
                delayTime = batchHasFailedItem && delayTime < this.failedDelay ? this.failedDelay : delayTime;
                if (delayTime > 0) {
                    setTimeout(() => this.notifyBatchAndQueue(nextItems), delayTime);
                }
                else {
                    this.notifyBatchAndQueue(nextItems);
                }
            }
        }
    }
    getNextCurrentItems() {
        const failedOrNotstartedInQueue = this.queueValue
            .filter(item => [
            QueueStatusEnum.failed,
            QueueStatusEnum.notstarted,
        ].includes(item.status));
        return failedOrNotstartedInQueue.slice(0, this.batchSize);
    }
    // Public methods
    add(items) {
        const newItems = items.filter(item => this.canAdd(item));
        return this.notifyQueueChange([...this.queueValue, ...newItems]);
    }
    remove(items) {
        const itemIdsToRemove = items
            .filter(item => this.canRemove(item))
            .map(item => item.id);
        const itemsAfterRemoval = this.queueValue
            .filter(item => !itemIdsToRemove.includes(item.id));
        this.notifyQueueChange(itemsAfterRemoval);
    }
    update(items) {
        const itemIdsToUpdate = items
            .filter(item => this.canUpdate(item))
            .map(item => item.id);
        const itemsAfterUpdate = this.queueValue
            .map(item => {
            if (itemIdsToUpdate.includes(item.id)) {
                const matchedItem = items.find(uItem => uItem.id === item.id);
                return matchedItem || item;
            }
            else {
                return item;
            }
        });
        this.notifyQueueChange(itemsAfterUpdate);
    }
    updateQueueBatch(items) {
        const itemIdsToUpdate = items.map(item => item.id);
        const currentBatchAfterUpdate = this.currentBatchValue
            .map(item => {
            if (itemIdsToUpdate.includes(item.id)) {
                const matchedItem = items.find(uItem => uItem.id === item.id);
                return matchedItem || item;
            }
            else {
                return item;
            }
        });
        // Update and notify queue only, but not current batch
        this.update(items);
        // if currentBatch is finished with completed or failed, then get Next batch and notify currentBatch
        const isBatchFinished = !currentBatchAfterUpdate.find(item => item.status === QueueStatusEnum.inprogress);
        if (isBatchFinished) {
            // notify next batch
            this.notifyCurrentBatchChange();
        }
    }
    // public Queue interaction methods
    start(batchSize = 1, minBatchTime = 0, // seconds
    failedDelay = 0) {
        if (!this.canStart())
            return;
        this.interval = setInterval(() => this.timer$.next(this.startTime), 1000);
        this.startTime = Date.now();
        this.batchSize = batchSize;
        this.minBatchTime = minBatchTime * 1000; // convert to milliseconds
        this.failedDelay = failedDelay * 1000; // convert to milliseconds
        this.notifyStatusChange(QueueStatusEnum.inprogress);
    }
    pause() {
        if (!this.canPause())
            return;
        this.notifyStatusChange(QueueStatusEnum.paused);
    }
    resume() {
        if (!this.canResume())
            return;
        this.notifyStatusChange(QueueStatusEnum.inprogress);
    }
    clear() {
        if (!this.canClear())
            return;
        this.interval && clearInterval(this.interval);
        this.interval = null;
        this.notifyQueueChange([]);
        this.notifyStatusChange(QueueStatusEnum.paused);
    }
}

// Export all exposable angular assets from ./src folder, like components, services, pipes, directives etc.

/**
 * Generated bundle index. Do not edit.
 */

export { Queue, QueueItem, QueueModule, QueueStatusComponent, QueueStatusEnum };
//# sourceMappingURL=annuadvent-ngx-tools-queue.mjs.map
